@@ -34,19 +34,19 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <source>Allow to add additional devices using the login QR code but never show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the QR-Code and password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -88,11 +88,11 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Copy JID</source>
+        <source>Copy password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Copy password</source>
+        <source>Copy chat address</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -381,34 +381,34 @@ Never show this QR code to anyone else. It would allow unlimited access to your
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
-        <source>Remove password completely</source>
+        <source>Don&apos;t expose your password in any way</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be included in the QR code anymore.
+        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
 You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+Consider storing the password somewhere else if you want to use your account on another device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Remove password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DisablePlainTextPasswordDisplay</name>
     <message>
-        <source>Do not show password as text</source>
+        <source>Don&apos;t show your password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be shown as text anymore.
-You won&apos;t be able to see your password as text again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+        <source>Your password will not be shown anymore but still exposed via the login QR code.
+You won&apos;t be able to see your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Do not show password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -551,7 +551,7 @@ Make sure that you backed it up if you want to use your account later.</source>
     </message>
     <message>
         <source>No valid login QR code found.</source>
-        <translation>Nebyl nalezen žádný platný přihlašovací kód QR.</translation>
+        <translation type="vanished">Nebyl nalezen žádný platný přihlašovací kód QR.</translation>
     </message>
 </context>
 <context>
@@ -1150,6 +1150,18 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <source>Could not connect to the server. Please check your internet connection or your server name.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 is online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is typing…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 paused typing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -1180,6 +1192,10 @@ Prosím zkontrolujte své připojení k internetu.</translation>
         <source>Connecting…</source>
         <translation type="unfinished">Připojování…</translation>
     </message>
+    <message>
+        <source>This QR code is not a valid login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeScanner</name>
@@ -1507,7 +1523,7 @@ Deletion of message history saved on server</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Configure whether this device can be used to log in on a new device</source>
+        <source>Configure whether this device can be used to log in on another device</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
