@@ -102,19 +102,35 @@ Cerciórese de tener una copia de respaldo de estos si quiere utilizar su cuenta
     </message>
     <message>
         <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
-        <translation>Permite añadir nuevos dispositivos usando un QR-Code, pero nunca muestra la contraseña como texto. Esta acción no se puede deshacer, así que considera almacenar la contraseña de otra manera antes de usarla.</translation>
+        <translation type="vanished">Permite añadir nuevos dispositivos usando un QR-Code, pero nunca muestra la contraseña como texto. Esta acción no se puede deshacer, así que considera almacenar la contraseña de otra manera antes de usarla.</translation>
     </message>
     <message>
         <source>Disable showing the password</source>
-        <translation>Deshabilitar mostrar la contraseña</translation>
+        <translation type="vanished">Deshabilitar mostrar la contraseña</translation>
     </message>
     <message>
         <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
-        <translation>No exponga la contraseña de ninguna manera. Esta acción no puede deshacerse.</translation>
+        <translation type="vanished">No exponga la contraseña de ninguna manera. Esta acción no puede deshacerse.</translation>
     </message>
     <message>
         <source>Disable showing the QR-Code and password</source>
-        <translation>Deshabilitar mostrar el QR-Code y la contraseña</translation>
+        <translation type="vanished">Deshabilitar mostrar el QR-Code y la contraseña</translation>
+    </message>
+    <message>
+        <source>Allow to add additional devices using the login QR code but never show the password.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose password in any way</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -128,10 +144,10 @@ Cerciórese de tener una copia de respaldo de estos si quiere utilizar su cuenta
 
 Attention:
 Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
-        <translation>Escanee el código QR o proporcione los datos de acceso como texto en otro dispositivo para acceder a la cuenta.
+        <translation>Escanee el código QR o proporcione los credenciales como texto en otro dispositivo para acceder a la cuenta.
 
 Atención:
-Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitado a su cuenta.</translation>
+¡Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitado a su cuenta!</translation>
     </message>
     <message>
         <source>Chat address:</source>
@@ -157,6 +173,14 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
         <source>Show as text</source>
         <translation>Mostrar como texto</translation>
     </message>
+    <message>
+        <source>Copy chat address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -193,7 +217,7 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Necesita conectarse para cambiar su contraseña.</translation>
+        <translation type="vanished">Necesita conectarse para cambiar su contraseña.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -207,6 +231,14 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
         <source>Change</source>
         <translation>Cambiar</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation type="unfinished">Error al cambiar la contraseña: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -258,7 +290,7 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Crear mensaje</translation>
+        <translation type="vanished">Crear mensaje</translation>
     </message>
     <message>
         <source>Send</source>
@@ -298,7 +330,7 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Insinuación de «spoiler»</translation>
+        <translation type="vanished">Insinuación de «spoiler»</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -322,7 +354,7 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
     </message>
     <message>
         <source>Close</source>
-        <translation>Cerrar</translation>
+        <translation type="vanished">Cerrar</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -334,7 +366,7 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
     </message>
     <message>
         <source>All files</source>
-        <translation>Todos los archivos</translation>
+        <translation type="vanished">Todos los archivos</translation>
     </message>
     <message>
         <source>Copy message</source>
@@ -352,6 +384,25 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
         <source>Quote message</source>
         <translation type="vanished">Citar mensaje</translation>
     </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation type="unfinished">Insinuación de «spoiler»</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation type="unfinished">Crear mensaje</translation>
+    </message>
 </context>
 <context>
     <name>ClientWorker</name>
@@ -406,6 +457,29 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
         <translation>Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished">Cambiar</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -413,42 +487,85 @@ Jamás muestre este código QR a otras personas, dado que brinda acceso ilimitad
         <translation type="vanished">Acciones</translation>
     </message>
 </context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
         <source>Remove password completely</source>
-        <translation>Eliminar la contraseña completamente</translation>
+        <translation type="vanished">Eliminar la contraseña completamente</translation>
     </message>
     <message>
         <source>Your password will not be included in the QR code anymore.
 You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
 Make sure that you backed it up if you want to use your account later.</source>
-        <translation>Tu contraseña ya no se incluirá en el código QR.
+        <translation type="vanished">Tu contraseña ya no se incluirá en el código QR.
 No podrás usar el inicio de sesión a través del código QR sin introducir tu contraseña de nuevo porque esta acción no se puede deshacer!
 Asegúrate de hacer una copia de seguridad si quieres usar tu cuenta más tarde.</translation>
     </message>
     <message>
         <source>Remove password</source>
-        <translation>Eliminar contraseña</translation>
+        <translation type="vanished">Eliminar contraseña</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose your password in any way</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose password in any way</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DisablePlainTextPasswordDisplay</name>
     <message>
         <source>Do not show password as text</source>
-        <translation>No mostrar la contraseña como texto</translation>
+        <translation type="vanished">No mostrar la contraseña como texto</translation>
     </message>
     <message>
         <source>Your password will not be shown as text anymore.
 You won&apos;t be able to see your password as text again because this action cannot be undone!
 Make sure that you backed it up if you want to use your account later.</source>
-        <translation>Tu contraseña ya no se mostrará como texto.
+        <translation type="vanished">Tu contraseña ya no se mostrará como texto.
 No podrás ver tu contraseña como texto de nuevo porque esta acción no se puede deshacer!
 Asegúrate de hacer una copia de seguridad si quieres usar tu cuenta más tarde.</translation>
     </message>
     <message>
         <source>Do not show password</source>
-        <translation>No mostrar contraseña</translation>
+        <translation type="vanished">No mostrar contraseña</translation>
+    </message>
+    <message>
+        <source>Don&apos;t show your password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown anymore but still exposed via the login QR code.
+You won&apos;t be able to see your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t show password</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -466,47 +583,47 @@ Asegúrate de hacer una copia de seguridad si quieres usar tu cuenta más tarde.
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Favoritos</translation>
+        <translation type="vanished">Favoritos</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Gente</translation>
+        <translation type="vanished">Gente</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Naturaleza</translation>
+        <translation type="vanished">Naturaleza</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Comida</translation>
+        <translation type="vanished">Comida</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Actividad</translation>
+        <translation type="vanished">Actividad</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Viajes</translation>
+        <translation type="vanished">Viajes</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Objetos</translation>
+        <translation type="vanished">Objetos</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Símbolos</translation>
+        <translation type="vanished">Símbolos</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Banderas</translation>
+        <translation type="vanished">Banderas</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Buscar</translation>
+        <translation type="vanished">Buscar</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Buscar emoyi</translation>
+        <translation type="vanished">Buscar emoyi</translation>
     </message>
 </context>
 <context>
@@ -637,7 +754,7 @@ Asegúrate de hacer una copia de seguridad si quieres usar tu cuenta más tarde.
     </message>
     <message>
         <source>No valid login QR code found.</source>
-        <translation>No se encontró ningún código QR de inicio de sesión válido.</translation>
+        <translation type="vanished">No se encontró ningún código QR de inicio de sesión válido.</translation>
     </message>
 </context>
 <context>
@@ -693,7 +810,7 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
     </message>
     <message>
         <source>Connect</source>
-        <translation>Conectar</translation>
+        <translation type="vanished">Conectar</translation>
     </message>
     <message>
         <source>Connecting…</source>
@@ -735,6 +852,41 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
         <source>Log in using a QR-Code</source>
         <translation type="vanished">Acceder mediante código QR</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -805,6 +957,37 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
         <source>%1 (%2)</source>
         <translation>%1 (%2)</translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished">Audio</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation type="unfinished">Documento</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished">Imagen</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation type="unfinished">Vídeo</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished">Archivo</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation type="unfinished">«Spoiler»</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -1026,7 +1209,7 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation>Preparado</translation>
+        <translation type="vanished">Preparado</translation>
     </message>
     <message>
         <source>Initializing…</source>
@@ -1070,36 +1253,60 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
         <source>Mark as read</source>
         <translation>Marcar como leído</translation>
     </message>
+    <message>
+        <source>Available</source>
+        <translation type="unfinished">Disponible</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="unfinished">Ausente</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="unfinished">No molestar</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="unfinished">Ausente por bastante tiempo</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="unfinished">Desconectado</translation>
+    </message>
 </context>
 <context>
     <name>QmlUtils</name>
     <message>
         <source>Available</source>
-        <translation>Disponible</translation>
+        <translation type="vanished">Disponible</translation>
     </message>
     <message>
         <source>Free for chat</source>
-        <translation>Libre para charlar</translation>
+        <translation type="vanished">Libre para charlar</translation>
     </message>
     <message>
         <source>Away</source>
-        <translation>Ausente</translation>
+        <translation type="vanished">Ausente</translation>
     </message>
     <message>
         <source>Do not disturb</source>
-        <translation>No molestar</translation>
+        <translation type="vanished">No molestar</translation>
     </message>
     <message>
         <source>Away for longer</source>
-        <translation>Ausente por bastante tiempo</translation>
+        <translation type="vanished">Ausente por bastante tiempo</translation>
     </message>
     <message>
         <source>Offline</source>
-        <translation>Desconectado</translation>
+        <translation type="vanished">Desconectado</translation>
     </message>
     <message>
         <source>Error</source>
-        <translation>Error</translation>
+        <translation type="vanished">Error</translation>
     </message>
     <message>
         <source>Invisible</source>
@@ -1123,7 +1330,7 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation>No se pudo resolver la dirección del servidor. Compruebe el nombre del servidor.</translation>
+        <translation type="vanished">No se pudo resolver la dirección del servidor. Compruebe el nombre del servidor.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
@@ -1149,6 +1356,22 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation>No se permite el acceso a internet. Compruebe la configuración de acceso a internet del sistema.</translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is typing…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 paused typing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -1158,24 +1381,68 @@ Tu contraseña será eliminada, ¡asegúrate de que esté almacenada en un gesto
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
-        <translation>Escanear código QR</translation>
+        <translation type="unfinished">Escanear código QR</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished">Mostrar explicación</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished">Continuar sin código QR</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished">Escanee el código QR desde su dispositivo existente para transferir su cuenta.</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This QR code is not a valid login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="unfinished">No se admite el formato «%1» de la cámara.</translation>
     </message>
     <message>
         <source>There is no camera available.</source>
-        <translation>No hay ninguna cámara disponible.</translation>
+        <translation type="unfinished">No hay ninguna cámara disponible.</translation>
     </message>
     <message>
         <source>Your camera is busy.
 Try to close other applications using the camera.</source>
-        <translation>La cámara está ocupada.
+        <translation type="unfinished">La cámara está ocupada.
+Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
+    <message>
+        <source>Scan QR code</source>
+        <translation type="vanished">Escanear código QR</translation>
+    </message>
+    <message>
+        <source>There is no camera available.</source>
+        <translation type="vanished">No hay ninguna cámara disponible.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="vanished">La cámara está ocupada.
 Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>No se admite el formato «%1» de la cámara.</translation>
+        <translation type="vanished">No se admite el formato «%1» de la cámara.</translation>
     </message>
     <message>
         <source>Logging in…</source>
@@ -1183,23 +1450,23 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     </message>
     <message>
         <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation>Escanee el código QR desde su dispositivo existente para transferir su cuenta.</translation>
+        <translation type="vanished">Escanee el código QR desde su dispositivo existente para transferir su cuenta.</translation>
     </message>
     <message>
         <source>Show explanation</source>
-        <translation>Mostrar explicación</translation>
+        <translation type="vanished">Mostrar explicación</translation>
     </message>
     <message>
         <source>Scan</source>
-        <translation>Escanear</translation>
+        <translation type="vanished">Escanear</translation>
     </message>
     <message>
         <source>Continue without QR code</source>
-        <translation>Continuar sin código QR</translation>
+        <translation type="vanished">Continuar sin código QR</translation>
     </message>
     <message>
         <source>Connecting…</source>
-        <translation>Conectar…</translation>
+        <translation type="vanished">Conectar…</translation>
     </message>
 </context>
 <context>
@@ -1221,11 +1488,11 @@ Pruebe a cerrar otras aplicaciones que utilicen la cámara.</translation>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Contraseña cambiada con éxito.</translation>
+        <translation type="vanished">Contraseña cambiada con éxito.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Error al cambiar la contraseña: %1</translation>
+        <translation type="vanished">Error al cambiar la contraseña: %1</translation>
     </message>
 </context>
 <context>
@@ -1288,7 +1555,7 @@ You will not be able to use your account again!</source>
     <name>RosterListItem</name>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Error: compruebe el JID.</translation>
+        <translation type="vanished">Error: compruebe el JID.</translation>
     </message>
     <message>
         <source>Available</source>
@@ -1335,7 +1602,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>«Spoiler»</translation>
+        <translation type="vanished">«Spoiler»</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1389,7 +1656,11 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>¿Realmente desea eliminar el contacto &lt;b&gt;%1&lt;/b&gt; de su lista?</translation>
+        <translation type="vanished">¿Realmente desea eliminar el contacto &lt;b&gt;%1&lt;/b&gt; de su lista?</translation>
+    </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1472,7 +1743,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>configure whether this device can be used to log in on a new device</source>
-        <translation>configurar si este dispositivo puede ser utilizado para iniciar sesión en un nuevo dispositivo</translation>
+        <translation type="vanished">configurar si este dispositivo puede ser utilizado para iniciar sesión en un nuevo dispositivo</translation>
     </message>
     <message>
         <source>Remove account from Kaidan</source>
@@ -1490,6 +1761,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation>Eliminar la cuenta del servidor</translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on another device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1521,7 +1804,7 @@ Deletion of message history saved on server</extracomment>
     <name>StartPage</name>
     <message>
         <source>Enjoy free communication on every device!</source>
-        <translation>Disfrute de comunicación libre y gratuita en cualquier dispositivo.</translation>
+        <translation>¡Disfrute de comunicación libre en cualquier dispositivo!</translation>
     </message>
     <message>
         <source>Let&apos;s start</source>
@@ -1569,7 +1852,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Archivo</translation>
+        <translation type="vanished">Archivo</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
@@ -1582,6 +1865,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation>Perfil</translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation type="unfinished">Cambiar nombre de contacto</translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
