@@ -27,19 +27,19 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <source>Allow to add additional devices using the login QR code but never show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the QR-Code and password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -81,11 +81,11 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Copy JID</source>
+        <source>Copy password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Copy password</source>
+        <source>Copy chat address</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -374,34 +374,34 @@ Never show this QR code to anyone else. It would allow unlimited access to your
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
-        <source>Remove password completely</source>
+        <source>Don&apos;t expose your password in any way</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be included in the QR code anymore.
+        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
 You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+Consider storing the password somewhere else if you want to use your account on another device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Remove password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DisablePlainTextPasswordDisplay</name>
     <message>
-        <source>Do not show password as text</source>
+        <source>Don&apos;t show your password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be shown as text anymore.
-You won&apos;t be able to see your password as text again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+        <source>Your password will not be shown anymore but still exposed via the login QR code.
+You won&apos;t be able to see your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Do not show password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -540,7 +540,7 @@ Make sure that you backed it up if you want to use your account later.</source>
     </message>
     <message>
         <source>No valid login QR code found.</source>
-        <translation>Nessun codice QR di accesso valido trovato.</translation>
+        <translation type="vanished">Nessun codice QR di accesso valido trovato.</translation>
     </message>
 </context>
 <context>
@@ -1069,6 +1069,18 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Could not connect to the server. Please check your internet connection or your server name.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 is online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is typing…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 paused typing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -1099,6 +1111,10 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Connecting…</source>
         <translation type="unfinished">Connessione…</translation>
     </message>
+    <message>
+        <source>This QR code is not a valid login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeScanner</name>
@@ -1426,7 +1442,7 @@ Deletion of message history saved on server</extracomment>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Configure whether this device can be used to log in on a new device</source>
+        <source>Configure whether this device can be used to log in on another device</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
