@@ -27,19 +27,19 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
+        <source>Allow to add additional devices using the login QR code but never show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
+        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Disable showing the QR-Code and password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -80,6 +80,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Show as text</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Copy chat address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangePassword</name>
@@ -107,10 +115,6 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Current password is invalid.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>You need to be connected to change your password.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
         <translation type="unfinished"></translation>
@@ -123,6 +127,14 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Change</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -156,18 +168,10 @@ Never show this QR code to anyone else. It would allow unlimited access to your
 </context>
 <context>
     <name>ChatPage</name>
-    <message>
-        <source>Compose message</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Send a spoiler message</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Spoiler hint</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Unmute notifications</source>
         <translation type="unfinished"></translation>
@@ -184,10 +188,6 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Search up</source>
         <translation type="unfinished"></translation>
@@ -197,7 +197,22 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>All files</source>
+        <source>Close message search bar</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Compose message</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -254,37 +269,75 @@ Never show this QR code to anyone else. It would allow unlimited access to your
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
-        <source>Remove password completely</source>
+        <source>Don&apos;t expose your password in any way</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be included in the QR code anymore.
+        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
 You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+Consider storing the password somewhere else if you want to use your account on another device.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Remove password</source>
+        <source>Don&apos;t expose password in any way</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DisablePlainTextPasswordDisplay</name>
     <message>
-        <source>Do not show password as text</source>
+        <source>Don&apos;t show your password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Your password will not be shown as text anymore.
-You won&apos;t be able to see your password as text again because this action cannot be undone!
-Make sure that you backed it up if you want to use your account later.</source>
+        <source>Your password will not be shown anymore but still exposed via the login QR code.
+You won&apos;t be able to see your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Do not show password</source>
+        <source>Don&apos;t show password</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -299,53 +352,6 @@ Make sure that you backed it up if you want to use your account later.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>EmojiPicker</name>
-    <message>
-        <source>Favorites</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>People</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Nature</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Food</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Activity</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Travel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Objects</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Symbols</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Flags</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Search</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Search emoji</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>EmptyChatPage</name>
     <message>
@@ -395,10 +401,6 @@ Make sure that you backed it up if you want to use your account later.</source>
         <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>No valid login QR code found.</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>LocalAccountRemoval</name>
@@ -431,7 +433,38 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Connect</source>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -504,6 +537,37 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>%1 (%2)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -624,10 +688,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
 </context>
 <context>
     <name>NewMedia</name>
-    <message>
-        <source>Ready</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Initializing…</source>
         <translation type="unfinished"></translation>
@@ -670,9 +730,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Mark as read</source>
         <translation type="unfinished"></translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation type="unfinished"></translation>
@@ -697,10 +754,9 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Offline</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Error</source>
-        <translation type="unfinished"></translation>
-    </message>
+</context>
+<context>
+    <name>QmlUtils</name>
     <message>
         <source>Invalid username or password.</source>
         <translation type="unfinished"></translation>
@@ -717,10 +773,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>Error while trying to connect securely.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
         <translation type="unfinished"></translation>
@@ -741,6 +793,22 @@ Your password will be deleted, make sure it is stored in a password manager or y
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is typing…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 paused typing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -750,11 +818,38 @@ Your password will be deleted, make sure it is stored in a password manager or y
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show explanation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This QR code is not a valid login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>There is no camera available.</source>
         <translation type="unfinished"></translation>
@@ -764,30 +859,6 @@ Your password will be deleted, make sure it is stored in a password manager or y
 Try to close other applications using the camera.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show explanation</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Scan</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Continue without QR code</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Connecting…</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>RegistrationLoginDecisionPage</name>
@@ -804,17 +875,6 @@ Try to close other applications using the camera.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>RegistrationManager</name>
-    <message>
-        <source>Password changed successfully.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Failed to change password: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>RemoteAccountDeletion</name>
     <message>
@@ -870,13 +930,6 @@ You will not be able to use your account again!</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>RosterListItem</name>
-    <message>
-        <source>Error: Please check the JID.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>RosterManager</name>
     <message>
@@ -887,10 +940,6 @@ You will not be able to use your account again!</source>
         <source>Could not remove contact, as a result of not being connected.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Spoiler</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
         <translation type="unfinished"></translation>
@@ -921,10 +970,6 @@ You will not be able to use your account again!</source>
 </context>
 <context>
     <name>RosterRemoveContactSheet</name>
-    <message>
-        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete contact</source>
         <translation type="unfinished"></translation>
@@ -937,6 +982,10 @@ You will not be able to use your account again!</source>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RosterRenameContactSheet</name>
@@ -1012,10 +1061,6 @@ Deletion of message history saved on server</extracomment>
         <source>Account security</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>configure whether this device can be used to log in on a new device</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Remove account from Kaidan</source>
         <translation type="unfinished"></translation>
@@ -1032,6 +1077,18 @@ Deletion of message history saved on server</extracomment>
         <source>Delete account from the server</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on another device</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SettingsPage</name>
@@ -1076,10 +1133,6 @@ Deletion of message history saved on server</extracomment>
         <source>Could not send file, as a result of not being connected.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>File</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Message could not be sent.</source>
         <translation type="unfinished"></translation>
@@ -1091,6 +1144,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
