@@ -47,19 +47,35 @@
     </message>
     <message>
         <source>Allow to add new devices using a QR-Code, but never show the password as text. This action can not be undone, so consider storing the password in another way before using it.</source>
-        <translation>Permitir adicionar novos aparelhos usando um Código-QR, mas nunca mostrar a palavra-passe como texto. Esta ação não poderá ser desfeita, porém, considere armazenar a palavra-passe de outra forma antes de usá-la.</translation>
+        <translation type="vanished">Permitir adicionar novos aparelhos usando um Código-QR, mas nunca mostrar a palavra-passe como texto. Esta ação não poderá ser desfeita, porém, considere armazenar a palavra-passe de outra forma antes de usá-la.</translation>
     </message>
     <message>
         <source>Disable showing the password</source>
-        <translation>Desativar visibilidade da palavra-passe</translation>
+        <translation type="vanished">Desativar visibilidade da palavra-passe</translation>
     </message>
     <message>
         <source>Don&apos;t expose the password in any form. This action can not be undone.</source>
-        <translation>Não mostra a palavra-passe de forma nenhuma. Esta ação não pode ser desfeita.</translation>
+        <translation type="vanished">Não mostra a palavra-passe de forma nenhuma. Esta ação não pode ser desfeita.</translation>
     </message>
     <message>
         <source>Disable showing the QR-Code and password</source>
-        <translation>Desativar a exibição do código QR e da palavra-passe</translation>
+        <translation type="vanished">Desativar a exibição do código QR e da palavra-passe</translation>
+    </message>
+    <message>
+        <source>Allow to add additional devices using the login QR code but never show the password.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t show password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose password in any way</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -102,6 +118,14 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
         <source>Show as text</source>
         <translation>Mostrar como texto</translation>
     </message>
+    <message>
+        <source>Copy chat address</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Copy password</source>
+        <translation>Copiar palavra-passe</translation>
+    </message>
 </context>
 <context>
     <name>BackButton</name>
@@ -138,7 +162,7 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
     </message>
     <message>
         <source>You need to be connected to change your password.</source>
-        <translation>Você tem que estar conectado para alterar sua palavra-passe.</translation>
+        <translation type="vanished">Você tem que estar conectado para alterar sua palavra-passe.</translation>
     </message>
     <message>
         <source>After changing your password, you will need to reenter it on all your other devices.</source>
@@ -152,6 +176,14 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
         <source>Change</source>
         <translation>Alterar</translation>
     </message>
+    <message>
+        <source>Password changed successfully</source>
+        <translation>Palavra-passe alterada com sucesso</translation>
+    </message>
+    <message>
+        <source>Failed to change password: %1</source>
+        <translation>Falhou ao alterar a palavra-passe: %1</translation>
+    </message>
 </context>
 <context>
     <name>ChatMessage</name>
@@ -187,7 +219,7 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
     <name>ChatPage</name>
     <message>
         <source>Compose message</source>
-        <translation>Compor mensagem</translation>
+        <translation type="vanished">Compor mensagem</translation>
     </message>
     <message>
         <source>Send</source>
@@ -223,7 +255,7 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
     </message>
     <message>
         <source>Spoiler hint</source>
-        <translation>Dica de spoiler</translation>
+        <translation type="vanished">Dica de spoiler</translation>
     </message>
     <message>
         <source>Unmute notifications</source>
@@ -243,7 +275,7 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
     </message>
     <message>
         <source>Close</source>
-        <translation>Fechar</translation>
+        <translation type="vanished">Fechar</translation>
     </message>
     <message>
         <source>Search up</source>
@@ -255,7 +287,26 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
     </message>
     <message>
         <source>All files</source>
-        <translation>Todos os ficheiros</translation>
+        <translation type="vanished">Todos os ficheiros</translation>
+    </message>
+    <message>
+        <source>Close message search bar</source>
+        <translation>Fechar barra de pesquisa de mensagens</translation>
+    </message>
+</context>
+<context>
+    <name>ChatPageSendingPane</name>
+    <message>
+        <source>Spoiler hint</source>
+        <translation>Dica de spoiler</translation>
+    </message>
+    <message>
+        <source>Close spoiler hint field</source>
+        <translation>Fechar campo de dica de spoiler</translation>
+    </message>
+    <message>
+        <source>Compose message</source>
+        <translation>Escrever mensagem</translation>
     </message>
 </context>
 <context>
@@ -311,6 +362,29 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
         <translation>Cancelar</translation>
     </message>
 </context>
+<context>
+    <name>ConnectionSettings</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Configurações de conexão</translation>
+    </message>
+    <message>
+        <source>Change</source>
+        <translation>Alterar</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation>Cancelar</translation>
+    </message>
+    <message>
+        <source>Connection settings could not be changed</source>
+        <translation>Não foi possível alterar as configurações de conexão</translation>
+    </message>
+    <message>
+        <source>Connection settings changed</source>
+        <translation>Configurações de conexão alteradas</translation>
+    </message>
+</context>
 <context>
     <name>ContextDrawer</name>
     <message>
@@ -318,42 +392,85 @@ Nunca mostre este código QR a ninguém. Ele permitiria o acesso ilimitado à su
         <translation type="vanished">Ações</translation>
     </message>
 </context>
+<context>
+    <name>CustomConnectionSettings</name>
+    <message>
+        <source>Hostname:</source>
+        <translation>Servidor:</translation>
+    </message>
+    <message>
+        <source>The hostname must not contain blank spaces</source>
+        <translation>O nome do servidor não pode conter espaços em branco</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Porta:</translation>
+    </message>
+</context>
 <context>
     <name>DisablePasswordDisplay</name>
     <message>
         <source>Remove password completely</source>
-        <translation>Apagar a palavra-passe completamente</translation>
+        <translation type="vanished">Apagar a palavra-passe completamente</translation>
     </message>
     <message>
         <source>Your password will not be included in the QR code anymore.
 You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
 Make sure that you backed it up if you want to use your account later.</source>
-        <translation>A sua palavra-passe ja não será incluída no código QR.
+        <translation type="vanished">A sua palavra-passe ja não será incluída no código QR.
 Não poderá usar o login via código QR sem inserir a sua palavra-passe novamente porque esta ação não pode ser desfeita!
 Certifique-se de que fez o backup se quiser usar sua conta mais tarde.</translation>
     </message>
     <message>
         <source>Remove password</source>
-        <translation>Apagar a palavra-passe</translation>
+        <translation type="vanished">Apagar a palavra-passe</translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose your password in any way</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
+You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t expose password in any way</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>DisablePlainTextPasswordDisplay</name>
     <message>
         <source>Do not show password as text</source>
-        <translation>Não mostre a palavra-passe como texto</translation>
+        <translation type="vanished">Não mostre a palavra-passe como texto</translation>
     </message>
     <message>
         <source>Your password will not be shown as text anymore.
 You won&apos;t be able to see your password as text again because this action cannot be undone!
 Make sure that you backed it up if you want to use your account later.</source>
-        <translation>A partir de agora a sua palavra-passe não será mais exibida como texto.
+        <translation type="vanished">A partir de agora a sua palavra-passe não será mais exibida como texto.
 Não será capaz de ver a sua palavra-passe como texto novamente, porque essa ação não pode ser desfeita!
 Certifique-se de fazer o backup dela se deseja usar a sua conta mais tarde.</translation>
     </message>
     <message>
         <source>Do not show password</source>
-        <translation>Não mostre a palavra-passe</translation>
+        <translation type="vanished">Não mostre a palavra-passe</translation>
+    </message>
+    <message>
+        <source>Don&apos;t show your password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Your password will not be shown anymore but still exposed via the login QR code.
+You won&apos;t be able to see your password again because this action cannot be undone!
+Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t show password</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -371,47 +488,47 @@ Certifique-se de fazer o backup dela se deseja usar a sua conta mais tarde.</tra
     <name>EmojiPicker</name>
     <message>
         <source>Favorites</source>
-        <translation>Favoritos</translation>
+        <translation type="vanished">Favoritos</translation>
     </message>
     <message>
         <source>People</source>
-        <translation>Pessoas</translation>
+        <translation type="vanished">Pessoas</translation>
     </message>
     <message>
         <source>Nature</source>
-        <translation>Natureza</translation>
+        <translation type="vanished">Natureza</translation>
     </message>
     <message>
         <source>Food</source>
-        <translation>Alimentos</translation>
+        <translation type="vanished">Alimentos</translation>
     </message>
     <message>
         <source>Activity</source>
-        <translation>Atividade</translation>
+        <translation type="vanished">Atividade</translation>
     </message>
     <message>
         <source>Travel</source>
-        <translation>Viagens</translation>
+        <translation type="vanished">Viagens</translation>
     </message>
     <message>
         <source>Objects</source>
-        <translation>Objetos</translation>
+        <translation type="vanished">Objetos</translation>
     </message>
     <message>
         <source>Symbols</source>
-        <translation>Símbolos</translation>
+        <translation type="vanished">Símbolos</translation>
     </message>
     <message>
         <source>Flags</source>
-        <translation>Bandeiras</translation>
+        <translation type="vanished">Bandeiras</translation>
     </message>
     <message>
         <source>Search</source>
-        <translation>Pesquisa</translation>
+        <translation type="vanished">Pesquisa</translation>
     </message>
     <message>
         <source>Search emoji</source>
-        <translation>Procurar emoji</translation>
+        <translation type="vanished">Procurar emoji</translation>
     </message>
 </context>
 <context>
@@ -459,11 +576,11 @@ Certifique-se de fazer o backup dela se deseja usar a sua conta mais tarde.</tra
     </message>
     <message>
         <source>Settings</source>
-        <translation type="unfinished">Configurações</translation>
+        <translation>Configurações</translation>
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Offline</translation>
+        <translation>Offline</translation>
     </message>
     <message>
         <source>Online</source>
@@ -487,7 +604,7 @@ Certifique-se de fazer o backup dela se deseja usar a sua conta mais tarde.</tra
     </message>
     <message>
         <source>No valid login QR code found.</source>
-        <translation>Não foi possível encontrar um código QR válido.</translation>
+        <translation type="vanished">Não foi possível encontrar um código QR válido.</translation>
     </message>
 </context>
 <context>
@@ -504,7 +621,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar</translation>
     </message>
 </context>
 <context>
@@ -539,7 +656,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Connect</source>
-        <translation>Conectar</translation>
+        <translation type="vanished">Conectar</translation>
     </message>
     <message>
         <source>Connecting…</source>
@@ -577,6 +694,41 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
         <source>An unknown error occured; see log for details.</source>
         <translation type="vanished">Ocorreu um erro desconhecido; consulte o registo para mais detalhes.</translation>
     </message>
+    <message>
+        <source>Connection settings</source>
+        <translation>Configurações de conexão</translation>
+    </message>
+</context>
+<context>
+    <name>LoginSettingsPage</name>
+    <message>
+        <source>Connection settings</source>
+        <translation>Configurações de conexão</translation>
+    </message>
+    <message>
+        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
+        <translation>As configurações da conexão serão salvas de forma permanente após a primeira autenticação. Se não funcionar, retorne para a página de login.</translation>
+    </message>
+    <message>
+        <source>Enable custom connection settings</source>
+        <translation>Ativar configurações de conexão avançadas</translation>
+    </message>
+    <message>
+        <source>Port:</source>
+        <translation>Porta:</translation>
+    </message>
+    <message>
+        <source>Hostname:</source>
+        <translation>Servidor:</translation>
+    </message>
+    <message>
+        <source>Reset</source>
+        <translation>Restaurar</translation>
+    </message>
+    <message>
+        <source>Apply</source>
+        <translation>Aplicar</translation>
+    </message>
 </context>
 <context>
     <name>MediaRecorder</name>
@@ -647,6 +799,37 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
         <source>%1 (%2)</source>
         <translation>%1 (%2)</translation>
     </message>
+    <message>
+        <source>Audio</source>
+        <translation>Áudio</translation>
+    </message>
+    <message>
+        <source>Document</source>
+        <translation>Documento</translation>
+    </message>
+    <message>
+        <source>Location</source>
+        <translation>Local</translation>
+    </message>
+    <message>
+        <source>Image</source>
+        <translation>Imagem</translation>
+    </message>
+    <message>
+        <source>Video</source>
+        <translation>Vídeo</translation>
+    </message>
+    <message>
+        <source>File</source>
+        <translation>Ficheiro</translation>
+    </message>
+</context>
+<context>
+    <name>Message</name>
+    <message>
+        <source>Spoiler</source>
+        <translation>Spoiler</translation>
+    </message>
 </context>
 <context>
     <name>MessageHandler</name>
@@ -667,19 +850,19 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     <name>MessageModel</name>
     <message>
         <source>Pending</source>
-        <translation type="unfinished"></translation>
+        <translation>Aguardando</translation>
     </message>
     <message>
         <source>Sent</source>
-        <translation type="unfinished"></translation>
+        <translation>Enviado</translation>
     </message>
     <message>
         <source>Delivered</source>
-        <translation type="unfinished"></translation>
+        <translation>Entregue</translation>
     </message>
     <message>
         <source>Error</source>
-        <translation type="unfinished"></translation>
+        <translation>Erro</translation>
     </message>
 </context>
 <context>
@@ -718,15 +901,15 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Image</source>
-        <translation type="unfinished">Imagem</translation>
+        <translation>Imagem</translation>
     </message>
     <message>
         <source>Audio</source>
-        <translation type="unfinished">Áudio</translation>
+        <translation>Áudio</translation>
     </message>
     <message>
         <source>Video</source>
-        <translation type="unfinished">Vídeo</translation>
+        <translation>Vídeo</translation>
     </message>
     <message>
         <source>Codec</source>
@@ -754,7 +937,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Initializing…</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
@@ -762,7 +945,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Recording…</source>
-        <translation type="unfinished"></translation>
+        <translation>Gravando…</translation>
     </message>
     <message>
         <source>Paused</source>
@@ -788,11 +971,11 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     <name>NewMedia</name>
     <message>
         <source>Ready</source>
-        <translation>Pronto</translation>
+        <translation type="vanished">Pronto</translation>
     </message>
     <message>
         <source>Initializing…</source>
-        <translation type="unfinished"></translation>
+        <translation>Iniciando…</translation>
     </message>
     <message>
         <source>Unavailable</source>
@@ -800,7 +983,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Recording… %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Gravando… %1</translation>
     </message>
     <message>
         <source>Paused %1</source>
@@ -811,30 +994,27 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     <name>PasswordRemovalPage</name>
     <message>
         <source>Remove password</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar palavra-passe</translation>
     </message>
     <message>
         <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
-        <translation type="unfinished"></translation>
+        <translation>Pode decidir a não divulgar a sua palavra-passe para &lt;b&gt;%1&lt;/b&gt; como texto ou removê-lo completamente de transferência da conta. Se remover a palavra-passe completamente, não será capaz de usar transferência da conta a escanear, sem digitar a palavra-passe, porque ela também será removida do código QR.</translation>
     </message>
     <message>
         <source>Do not show password as text</source>
-        <translation type="unfinished"></translation>
+        <translation>Não mostrar palavra-passe como texto</translation>
     </message>
     <message>
         <source>Remove completely</source>
-        <translation type="unfinished"></translation>
+        <translation>Remover completamente</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Mark as read</source>
-        <translation type="unfinished"></translation>
+        <translation>Marcar como lido</translation>
     </message>
-</context>
-<context>
-    <name>QmlUtils</name>
     <message>
         <source>Available</source>
         <translation>Disponível</translation>
@@ -845,7 +1025,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Away</source>
-        <translation>Indisponível</translation>
+        <translation>Ausente</translation>
     </message>
     <message>
         <source>Do not disturb</source>
@@ -853,15 +1033,42 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Away for longer</source>
-        <translation>Indisponível por mais tempo</translation>
+        <translation>Ausente por mais tempo</translation>
     </message>
     <message>
         <source>Offline</source>
-        <translation type="unfinished">Offline</translation>
+        <translation>Offline</translation>
+    </message>
+</context>
+<context>
+    <name>QmlUtils</name>
+    <message>
+        <source>Available</source>
+        <translation type="vanished">Disponível</translation>
+    </message>
+    <message>
+        <source>Free for chat</source>
+        <translation type="vanished">Livre para bate-papo</translation>
+    </message>
+    <message>
+        <source>Away</source>
+        <translation type="vanished">Indisponível</translation>
+    </message>
+    <message>
+        <source>Do not disturb</source>
+        <translation type="vanished">Não perturbe</translation>
+    </message>
+    <message>
+        <source>Away for longer</source>
+        <translation type="vanished">Indisponível por mais tempo</translation>
+    </message>
+    <message>
+        <source>Offline</source>
+        <translation type="obsolete">Offline</translation>
     </message>
     <message>
         <source>Error</source>
-        <translation>Erro</translation>
+        <translation type="vanished">Erro</translation>
     </message>
     <message>
         <source>Invalid username or password.</source>
@@ -869,19 +1076,19 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Cannot connect to the server. Please check your internet connection.</source>
-        <translation type="unfinished">Não é possível conectar ao servidor. Por favor, verifique a sua ligação à Internet.</translation>
+        <translation>Não é possível conectar ao servidor. Por favor, verifique a sua conexão de internet.</translation>
     </message>
     <message>
         <source>The server doesn&apos;t support secure connections.</source>
-        <translation type="unfinished">O servidor não suporta conexões seguras.</translation>
+        <translation>O servidor não suporta conexões seguras.</translation>
     </message>
     <message>
         <source>Error while trying to connect securely.</source>
-        <translation type="unfinished">Erro ao tentar conectar com segurança.</translation>
+        <translation>Erro ao tentar conectar-se de modo seguro.</translation>
     </message>
     <message>
         <source>Could not resolve the server&apos;s address. Please check your server name.</source>
-        <translation>Não foi possível resolver o endereço do servidor. Verifique o nome do seu servidor.</translation>
+        <translation type="vanished">Não foi possível resolver o endereço do servidor. Verifique o nome do seu servidor.</translation>
     </message>
     <message>
         <source>Could not connect to the server.</source>
@@ -889,7 +1096,7 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
     <message>
         <source>Authentification protocol not supported by the server.</source>
-        <translation type="unfinished">Protocolo de autenticação não suportado pelo servidor.</translation>
+        <translation>O protocolo de autenticação não é compatível com o servidor.</translation>
     </message>
     <message>
         <source>This server does not support registration.</source>
@@ -907,6 +1114,22 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
         <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
         <translation>O acesso à Internet não é permitido. Por favor, verifique a configuração de acesso à Internet do seu sistema.</translation>
     </message>
+    <message>
+        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
+        <translation>Não foi possível conectar com o servidor. Verifique a sua conexão com a internet ou o nome do seu servidor.</translation>
+    </message>
+    <message>
+        <source>%1 is online</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is typing…</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 paused typing</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QrCodeGenerator</name>
@@ -916,44 +1139,84 @@ A sua palavra-passe também será apagada, certifique-se de que ela é armazenad
     </message>
 </context>
 <context>
-    <name>QrCodeScannerPage</name>
+    <name>QrCodeOnboardingPage</name>
     <message>
         <source>Scan QR code</source>
-        <translation>Digitalizar código QR</translation>
+        <translation>Escanear código QR</translation>
+    </message>
+    <message>
+        <source>Show explanation</source>
+        <translation>Mostrar explicação</translation>
+    </message>
+    <message>
+        <source>Continue without QR code</source>
+        <translation>Continue sem código QR</translation>
+    </message>
+    <message>
+        <source>Scan the QR code from your existing device to transfer your account.</source>
+        <translation>Escaneie o código QR do aparelho existente para transferir a sua conta.</translation>
+    </message>
+    <message>
+        <source>Connecting…</source>
+        <translation>Conectando…</translation>
+    </message>
+    <message>
+        <source>This QR code is not a valid login QR code.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScanner</name>
+    <message>
+        <source>The camera format &apos;%1&apos; is not supported.</source>
+        <translation>O formato da câmara &apos;%1&apos; não é compatível.</translation>
     </message>
     <message>
         <source>There is no camera available.</source>
-        <translation>Não há câmaras disponíveis.</translation>
+        <translation>Não há câmara disponível.</translation>
     </message>
     <message>
         <source>Your camera is busy.
 Try to close other applications using the camera.</source>
         <translation>A sua câmara está em uso.
+Tente fechar outras aplicações que estão a usar a câmara.</translation>
+    </message>
+</context>
+<context>
+    <name>QrCodeScannerPage</name>
+    <message>
+        <source>Scan QR code</source>
+        <translation type="vanished">Digitalizar código QR</translation>
+    </message>
+    <message>
+        <source>There is no camera available.</source>
+        <translation type="vanished">Não há câmaras disponíveis.</translation>
+    </message>
+    <message>
+        <source>Your camera is busy.
+Try to close other applications using the camera.</source>
+        <translation type="vanished">A sua câmara está em uso.
 Tente fechar outras aplicações que estão a usar a câmara.</translation>
     </message>
     <message>
         <source>The camera format &apos;%1&apos; is not supported.</source>
-        <translation>O formato da câmara &apos;%1&apos; não é compatível.</translation>
+        <translation type="vanished">O formato da câmara &apos;%1&apos; não é compatível.</translation>
     </message>
     <message>
         <source>Scan the QR code from your existing device to transfer your account.</source>
-        <translation>Escaneie o código QR do aparelho existente para transferir a sua conta.</translation>
+        <translation type="vanished">Escaneie o código QR do aparelho existente para transferir a sua conta.</translation>
     </message>
     <message>
         <source>Show explanation</source>
-        <translation>Mostrar explicação</translation>
+        <translation type="vanished">Mostrar explicação</translation>
     </message>
     <message>
         <source>Scan</source>
-        <translation>Escaneie</translation>
+        <translation type="vanished">Escaneie</translation>
     </message>
     <message>
         <source>Continue without QR code</source>
-        <translation>Continue sem código QR</translation>
-    </message>
-    <message>
-        <source>Connecting…</source>
-        <translation type="unfinished"></translation>
+        <translation type="vanished">Continue sem código QR</translation>
     </message>
 </context>
 <context>
@@ -975,38 +1238,39 @@ Tente fechar outras aplicações que estão a usar a câmara.</translation>
     <name>RegistrationManager</name>
     <message>
         <source>Password changed successfully.</source>
-        <translation>Palavra-passe alterada com êxito.</translation>
+        <translation type="vanished">Palavra-passe alterada com êxito.</translation>
     </message>
     <message>
         <source>Failed to change password: %1</source>
-        <translation>Falhou ao alterar a palavra-passe: %1</translation>
+        <translation type="vanished">Falhou ao alterar a palavra-passe: %1</translation>
     </message>
 </context>
 <context>
     <name>RemoteAccountDeletion</name>
     <message>
         <source>Delete account completely</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar a conta por completo</translation>
     </message>
     <message>
         <source>Your account will be deleted completely, which means from this app and from the server.
 You will not be able to use your account again!</source>
-        <translation type="unfinished"></translation>
+        <translation>A sua conta será apagada por completo, ou seja, desta aplicação e do servidor.
+Não poderá usar a sua conta novamente!</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar</translation>
     </message>
 </context>
 <context>
     <name>RosterAddContactSheet</name>
     <message>
         <source>Add new contact</source>
-        <translation type="unfinished">Adicionar novo contacto</translation>
+        <translation>Adicionar novo contato</translation>
     </message>
     <message>
         <source>user@example.org</source>
-        <translation type="unfinished">user@example.org</translation>
+        <translation>utilizador@exemplo.org</translation>
     </message>
     <message>
         <source>This will also send a request to access the presence of the contact.</source>
@@ -1045,7 +1309,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Error: Please check the JID.</source>
-        <translation>Erro: verifique o JID.</translation>
+        <translation type="vanished">Erro: verifique o JID.</translation>
     </message>
 </context>
 <context>
@@ -1060,7 +1324,7 @@ You will not be able to use your account again!</source>
     </message>
     <message>
         <source>Spoiler</source>
-        <translation>Spoiler</translation>
+        <translation type="vanished">Spoiler</translation>
     </message>
     <message>
         <source>Could not rename contact, as a result of not being connected.</source>
@@ -1094,7 +1358,7 @@ You will not be able to use your account again!</source>
     <name>RosterRemoveContactSheet</name>
     <message>
         <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your roster?</source>
-        <translation>Realmente deseja apagar o contato &lt;b&gt;%1&lt;/b&gt; da sua lista?</translation>
+        <translation type="vanished">Realmente deseja apagar o contato &lt;b&gt;%1&lt;/b&gt; da sua lista?</translation>
     </message>
     <message>
         <source>Delete contact</source>
@@ -1108,6 +1372,10 @@ You will not be able to use your account again!</source>
         <source>Delete</source>
         <translation>Apagar</translation>
     </message>
+    <message>
+        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
+        <translation>Deseja realmente apagar o contato &lt;b&gt;%1&lt;/b&gt; da sua lista de contatos?</translation>
+    </message>
 </context>
 <context>
     <name>RosterRenameContactSheet</name>
@@ -1128,7 +1396,7 @@ You will not be able to use your account again!</source>
     <name>SendMediaSheet</name>
     <message>
         <source>Send</source>
-        <translation type="unfinished">Enviar</translation>
+        <translation>Enviar</translation>
     </message>
     <message>
         <source>Caption</source>
@@ -1161,7 +1429,7 @@ Deletion of message history saved on server</extracomment>
     <name>SettingsContent</name>
     <message>
         <source>Change password</source>
-        <translation type="unfinished">Mudar a palavra-passe</translation>
+        <translation>Alterar palavra-passe</translation>
     </message>
     <message>
         <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
@@ -1177,30 +1445,38 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>Settings</source>
-        <translation type="unfinished">Configurações</translation>
+        <translation>Configurações</translation>
     </message>
     <message>
         <source>Account security</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>configure whether this device can be used to log in on a new device</source>
-        <translation type="unfinished"></translation>
+        <translation>Segurança da conta</translation>
     </message>
     <message>
         <source>Remove account from Kaidan</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar conta de Kaidan</translation>
     </message>
     <message>
         <source>Remove account from this app</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar conta desta app</translation>
     </message>
     <message>
         <source>Delete account</source>
-        <translation type="unfinished"></translation>
+        <translation>Apagar conta</translation>
     </message>
     <message>
         <source>Delete account from the server</source>
+        <translation>Apagar conta do servidor</translation>
+    </message>
+    <message>
+        <source>Connection Settings</source>
+        <translation>Configurações de conexão</translation>
+    </message>
+    <message>
+        <source>Configure the hostname and port to connect to</source>
+        <translation>Configure o servidor e a porta para conexão</translation>
+    </message>
+    <message>
+        <source>Configure whether this device can be used to log in on another device</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1260,11 +1536,11 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>File</source>
-        <translation>Ficheiro</translation>
+        <translation type="vanished">Ficheiro</translation>
     </message>
     <message>
         <source>Message could not be sent.</source>
-        <translation type="unfinished"></translation>
+        <translation>Não foi possível enviar a mensagem.</translation>
     </message>
 </context>
 <context>
@@ -1273,6 +1549,22 @@ Deletion of message history saved on server</extracomment>
         <source>Profile</source>
         <translation>Perfil</translation>
     </message>
+    <message>
+        <source>Rename contact</source>
+        <translation>Renomear contato</translation>
+    </message>
+    <message>
+        <source>Show QR code</source>
+        <translation>Mostrar código QR</translation>
+    </message>
+    <message>
+        <source>Remove contact</source>
+        <translation>Remover contato</translation>
+    </message>
+    <message>
+        <source>Online devices</source>
+        <translation>Aparelhos online</translation>
+    </message>
 </context>
 <context>
     <name>VCardModel</name>
@@ -1286,7 +1578,7 @@ Deletion of message history saved on server</extracomment>
     </message>
     <message>
         <source>About</source>
-        <translation type="unfinished">Sobre</translation>
+        <translation>Sobre</translation>
     </message>
     <message>
         <source>Email</source>
