@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -63,10 +63,14 @@ AvatarFileStorage::AvatarFileStorage(QObject *parent) : QObject(parent)
 			QString line = stream.readLine();
 			while (!line.isNull()) {
 				// get hash and jid from line (seperated by a blank)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+				QStringList list = line.split(' ', Qt::SkipEmptyParts);
+#else
 				QStringList list = line.split(' ', QString::SkipEmptyParts);
+#endif
 
 				// set the hash for the jid
-				jidAvatarMap[list.at(1)] = list.at(0);
+				m_jidAvatarMap[list.at(1)] = list.at(0);
 
 				// read the next line
 				line = stream.readLine();
@@ -84,11 +88,11 @@ AvatarFileStorage::AddAvatarResult AvatarFileStorage::addAvatar(const QString &j
 
 	// generate a hexadecimal hash of the raw avatar
 	result.hash = QString(QCryptographicHash::hash(avatar, QCryptographicHash::Sha1).toHex());
-	QString oldHash = jidAvatarMap[jid];
+	QString oldHash = m_jidAvatarMap[jid];
 
 	// set the new hash and the `hasChanged` tag
 	if (oldHash != result.hash) {
-		jidAvatarMap[jid] = result.hash;
+		m_jidAvatarMap[jid] = result.hash;
 		result.hasChanged = true;
 
 		// delete the avatar if it isn't used anymore
@@ -125,14 +129,14 @@ AvatarFileStorage::AddAvatarResult AvatarFileStorage::addAvatar(const QString &j
 void AvatarFileStorage::clearAvatar(QString &jid)
 {
 	QString oldHash;
-	if (jidAvatarMap.contains(jid))
-		oldHash = jidAvatarMap[jid];
+	if (m_jidAvatarMap.contains(jid))
+		oldHash = m_jidAvatarMap[jid];
 
 	// if user had no avatar before, just return
 	if (oldHash.isEmpty())
 		return;
 
-	jidAvatarMap.remove(jid);
+	m_jidAvatarMap.remove(jid);
 	saveAvatarsFile();
 	cleanUp(oldHash);
 	emit avatarIdsChanged();
@@ -144,7 +148,7 @@ void AvatarFileStorage::cleanUp(QString &oldHash)
 		return;
 
 	// check if the same avatar is still used by another account
-	if (std::find(jidAvatarMap.cbegin(), jidAvatarMap.cend(), oldHash) != jidAvatarMap.cend())
+	if (std::find(m_jidAvatarMap.cbegin(), m_jidAvatarMap.cend(), oldHash) != m_jidAvatarMap.cend())
 		return;
 
 	// delete the old avatar locally
@@ -163,7 +167,7 @@ QString AvatarFileStorage::getAvatarPath(const QString &hash) const
 
 QString AvatarFileStorage::getHashOfJid(const QString& jid) const
 {
-	return jidAvatarMap[jid];
+	return m_jidAvatarMap[jid];
 }
 
 QString AvatarFileStorage::getAvatarPathOfJid(const QString& jid) const
@@ -191,8 +195,8 @@ void AvatarFileStorage::saveAvatarsFile()
 		return;
 
 	QTextStream out(&file);
-	const QStringList jidAvatarKeys = jidAvatarMap.keys();
+	const QStringList jidAvatarKeys = m_jidAvatarMap.keys();
 	for (const auto &jid : jidAvatarKeys)
 		/*     < HASH >            < JID >  */
-		out << jidAvatarMap[jid] << " " << jid << "\n";
+		out << m_jidAvatarMap[jid] << " " << jid << "\n";
 }
