@@ -30,16 +30,13 @@
 
 #include "ClientWorker.h"
 // Qt
-#include <QDebug>
-#include <QString>
-#include <QSysInfo>
+#include <QGuiApplication>
+#include <QSettings>
 // QXmpp
-#include <QXmppClient.h>
-#include <QXmppConfiguration.h>
 #include <QXmppUtils.h>
-#include <QXmppVersionManager.h>
 // Kaidan
 #include "AccountManager.h"
+#include "AvatarFileStorage.h"
 #include "DiscoveryManager.h"
 #include "DownloadManager.h"
 #include "Enums.h"
@@ -48,30 +45,53 @@
 #include "LogHandler.h"
 #include "MessageDb.h"
 #include "MessageHandler.h"
+#include "MessageModel.h"
+#include "PresenceCache.h"
 #include "RegistrationManager.h"
 #include "RosterDb.h"
 #include "RosterManager.h"
+#include "RosterModel.h"
+#include "ServerFeaturesCache.h"
+#include "TransferCache.h"
 #include "UploadManager.h"
+#include "VCardCache.h"
 #include "VCardManager.h"
 #include "VersionManager.h"
 
-ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
-	: QObject(parent), m_caches(caches), m_enableLogging(enableLogging), m_isApplicationWindowActive(true)
+ClientWorker::Caches::Caches(QObject *parent)
+	: settings(new QSettings(APPLICATION_NAME, APPLICATION_NAME)),
+	  vCardCache(new VCardCache(parent)),
+	  accountManager(new AccountManager(settings, vCardCache, parent)),
+	  msgModel(new MessageModel(parent)),
+	  rosterModel(new RosterModel(parent)),
+	  avatarStorage(new AvatarFileStorage(parent)),
+	  serverFeaturesCache(new ServerFeaturesCache(parent)),
+	  presCache(new PresenceCache(parent)),
+	  transferCache(new TransferCache(parent))
 {
-	m_client = new QXmppClient(this);
+	rosterModel->setMessageModel(msgModel);
+}
 
-	m_logger = new LogHandler(m_client, this);
-	m_logger->enableLogging(enableLogging);
-
-	m_vCardManager = new VCardManager(this, m_client, m_caches->avatarStorage, this);
-	m_registrationManager = new RegistrationManager(this, m_client, m_caches->settings, this);
-	m_rosterManager = new RosterManager(m_client,  m_caches->rosterModel, m_caches->avatarStorage, m_vCardManager, this);
-	m_messageHandler = new MessageHandler(this, m_client, m_caches->msgModel, this);
-	m_discoveryManager = new DiscoveryManager(m_client, this);
-	m_uploadManager = new UploadManager(m_client, m_rosterManager, this);
-	m_downloadManager = new DownloadManager(caches->transferCache, caches->msgModel, this);
-	m_versionManager = new VersionManager(m_client, this);
+ClientWorker::Caches::~Caches()
+{
+	delete settings;
+}
 
+ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
+	: QObject(parent),
+	  m_caches(caches),
+	  m_client(new QXmppClient(this)),
+	  m_logger(new LogHandler(m_client, enableLogging, this)),
+	  m_enableLogging(enableLogging),
+	  m_registrationManager(new RegistrationManager(this, m_client, m_caches->settings, this)),
+	  m_vCardManager(new VCardManager(this, m_client, m_caches->avatarStorage, this)),
+	  m_rosterManager(new RosterManager(m_client, m_caches->avatarStorage, m_vCardManager, this)),
+	  m_messageHandler(new MessageHandler(this, m_client, this)),
+	  m_discoveryManager(new DiscoveryManager(m_client, this)),
+	  m_uploadManager(new UploadManager(m_client, m_rosterManager, this)),
+	  m_downloadManager(new DownloadManager(caches->transferCache, this)),
+	  m_versionManager(new VersionManager(m_client, this))
+{
 	connect(m_client, &QXmppClient::connected, this, &ClientWorker::onConnected);
 	connect(m_client, &QXmppClient::disconnected, this, &ClientWorker::onDisconnected);
 
@@ -86,17 +106,18 @@ ClientWorker::ClientWorker(Caches *caches, bool enableLogging, QObject* parent)
 	connect(m_client, &QXmppClient::presenceReceived, caches->presCache, &PresenceCache::updatePresence);
 	connect(m_client, &QXmppClient::disconnected, caches->presCache, &PresenceCache::clear);
 
-	// Inform the client worker when the application window becomes active or inactive.
-	connect(Kaidan::instance(), &Kaidan::applicationWindowActiveChanged, this, &ClientWorker::setIsApplicationWindowActive);
-
-	// Reduce the network traffic when the application window is inactive.
-	connect(Kaidan::instance(), &Kaidan::applicationWindowActiveChanged, m_client, &QXmppClient::setActive);
+	// Reduce the network traffic when the application window is not active.
+	connect(qGuiApp, &QGuiApplication::applicationStateChanged, [=](Qt::ApplicationState state) {
+		if (state == Qt::ApplicationActive) {
+			m_client->setActive(true);
+		} else {
+			m_client->setActive(false);
+		}
+	});
 
 	// account deletion
 	connect(Kaidan::instance(), &Kaidan::deleteAccountFromClient, this, &ClientWorker::deleteAccountFromClient);
 	connect(Kaidan::instance(), &Kaidan::deleteAccountFromClientAndServer, this, &ClientWorker::deleteAccountFromClientAndServer);
-	connect(this, &ClientWorker::deleteAccountFromDatabase, Kaidan::instance()->rosterDb(), &RosterDb::clearAll);
-	connect(this, &ClientWorker::deleteAccountFromDatabase, Kaidan::instance()->messageDb(), &MessageDb::removeAllMessages);
 }
 
 void ClientWorker::initialize()
@@ -106,16 +127,6 @@ void ClientWorker::initialize()
 	qsrand(time(nullptr));
 }
 
-VCardManager *ClientWorker::vCardManager() const
-{
-	return m_vCardManager;
-}
-
-ClientWorker::Caches *ClientWorker::caches() const
-{
-	return m_caches;
-}
-
 void ClientWorker::startTask(const std::function<void ()> task) {
 	if (m_client->isAuthenticated()) {
 		task();
@@ -250,9 +261,7 @@ void ClientWorker::deleteAccountFromClient()
 	// If the client is already disconnected, delete the account directly from the client.
 	// Otherwise, disconnect first and delete the account afterwards.
 	if (!m_client->isAuthenticated()) {
-		emit deleteAccountFromDatabase();
-		AccountManager::instance()->deleteSettings();
-		AccountManager::instance()->deleteCredentials();
+		AccountManager::instance()->removeAccount(m_client->configuration().jidBare());
 		m_isAccountToBeDeletedFromClient = false;
 	} else {
 		m_isAccountToBeDeletedFromClient = true;
@@ -275,11 +284,6 @@ void ClientWorker::handleAccountDeletionFromServerFailed(const QXmppStanza::Erro
 		logOut();
 }
 
-bool ClientWorker::isApplicationWindowActive() const
-{
-	return m_isApplicationWindowActive;
-}
-
 void ClientWorker::onConnected()
 {
 	// no mutex needed, because this is called from updateClient()
@@ -320,7 +324,7 @@ void ClientWorker::onConnected()
 	// automatically in case of a connection outage.
 	m_client->configuration().setAutoReconnectionEnabled(true);
 
-	m_caches->msgModel->sendPendingMessages();
+	MessageModel::instance()->sendPendingMessages();
 }
 
 void ClientWorker::onDisconnected()
@@ -397,11 +401,6 @@ void ClientWorker::onConnectionError(QXmppClient::Error error)
 	}
 }
 
-void ClientWorker::setIsApplicationWindowActive(bool active)
-{
-	m_isApplicationWindowActive = active;
-}
-
 bool ClientWorker::startPendingTasks()
 {
 	bool isBusy = false;
