@@ -31,31 +31,29 @@
 #pragma once
 
 // Qt
-#include <QList>
-#include <QObject>
-#include <QSettings>
 // QXmpp
 #include <QXmppClient.h>
 // Kaidan
-#include "AccountManager.h"
-#include "AvatarFileStorage.h"
 #include "Enums.h"
-#include "MessageModel.h"
-#include "PresenceCache.h"
-#include "RosterModel.h"
-#include "ServerFeaturesCache.h"
-#include "TransferCache.h"
+
 class AccountManager;
+class AvatarFileStorage;
+class DiscoveryManager;
+class DownloadManager;
 class LogHandler;
-class ClientWorker;
+class MessageHandler;
+class MessageModel;
+class PresenceCache;
 class RegistrationManager;
 class RosterManager;
-class MessageHandler;
-class DiscoveryManager;
-class VCardManager;
+class RosterModel;
+class ServerFeaturesCache;
+class TransferCache;
 class UploadManager;
-class DownloadManager;
+class VCardCache;
+class VCardManager;
 class VersionManager;
+class QSettings;
 
 /**
  * The ClientWorker is used as a QObject-based worker on the ClientThread.
@@ -64,6 +62,15 @@ class ClientWorker : public QObject
 {
 	Q_OBJECT
 
+	Q_PROPERTY(RegistrationManager* registrationManager READ registrationManager CONSTANT)
+	Q_PROPERTY(VCardManager* vCardManager READ vCardManager CONSTANT)
+	Q_PROPERTY(RosterManager* rosterManager READ rosterManager CONSTANT)
+	Q_PROPERTY(MessageHandler* messageHandler READ messageHandler CONSTANT)
+	Q_PROPERTY(DiscoveryManager* discoveryManager READ discoveryManager CONSTANT)
+	Q_PROPERTY(UploadManager* uploadManager READ uploadManager CONSTANT)
+	Q_PROPERTY(DownloadManager* downloadManager READ downloadManager CONSTANT)
+	Q_PROPERTY(VersionManager* versionManager READ versionManager CONSTANT)
+
 public:
 	/**
 	 * enumeration of possible connection errors
@@ -84,25 +91,11 @@ public:
 	Q_ENUM(ConnectionError)
 
 	struct Caches {
-		Caches(RosterDb *rosterDb, MessageDb *msgDb, QObject *parent = nullptr)
-			: settings(new QSettings(APPLICATION_NAME, APPLICATION_NAME)),
-			  accountManager(new AccountManager(settings, parent)),
-			  msgModel(new MessageModel(msgDb, parent)),
-			  rosterModel(new RosterModel(rosterDb, parent)),
-		          avatarStorage(new AvatarFileStorage(parent)),
-		          serverFeaturesCache(new ServerFeaturesCache(parent)),
-		          presCache(new PresenceCache(parent)),
-			  transferCache(new TransferCache(parent))
-		{
-			rosterModel->setMessageModel(msgModel);
-		}
-
-		~Caches()
-		{
-			delete settings;
-		}
+		Caches(QObject *parent = nullptr);
+		~Caches();
 
 		QSettings *settings;
+		VCardCache *vCardCache;
 		AccountManager *accountManager;
 		MessageModel *msgModel;
 		RosterModel *rosterModel;
@@ -124,19 +117,50 @@ public:
 	 */
 	void initialize();
 
-	VCardManager *vCardManager() const;
+	RegistrationManager *registrationManager() const
+	{
+		return m_registrationManager;
+	}
 
-	/**
-	 * Returns all models and caches.
-	 */
-	Caches *caches() const;
+	VCardManager *vCardManager() const
+	{
+		return m_vCardManager;
+	}
 
-	/**
-	 * Returns whether the application window is active.
-	 *
-	 * The application window is active when it is in the foreground and focused.
-	 */
-	bool isApplicationWindowActive() const;
+	RosterManager *rosterManager() const
+	{
+		return m_rosterManager;
+	}
+
+	MessageHandler *messageHandler() const
+	{
+		return m_messageHandler;
+	}
+
+	DiscoveryManager *discoveryManager() const
+	{
+		return m_discoveryManager;
+	}
+
+	UploadManager *uploadManager() const
+	{
+		return m_uploadManager;
+	}
+
+	DownloadManager *downloadManager() const
+	{
+		return m_downloadManager;
+	}
+
+	VersionManager *versionManager() const
+	{
+		return m_versionManager;
+	}
+
+	Caches *caches() const
+	{
+		return m_caches;
+	}
 
 	/**
 	 * Starts or enqueues a task which will be executed after successful login (e.g. a
@@ -225,15 +249,6 @@ signals:
 	 */
 	void loggedInWithNewCredentials();
 
-	/**
-	 * Requests to show a notification for a chat message via the system's notification channel.
-	 *
-	 * @param senderJid JID of the message's sender
-	 * @param senderName name of the message's sender
-	 * @param message message to show
-	 */
-	void showMessageNotificationRequested(const QString &senderJid, const QString &senderName, const QString &message);
-
 	/**
 	 * Emitted when the client's connection state changed.
 	 *
@@ -248,19 +263,7 @@ signals:
 	 */
 	void connectionErrorChanged(ClientWorker::ConnectionError error);
 
-	/**
-	 * Deletes data related to the current account (messages, contacts etc.) from the database.
-	 */
-	void deleteAccountFromDatabase();
-
 private slots:
-	/**
-	 * Sets the value to know whether the application window is active.
-	 *
-	 * @param active true if the application window is active, false otherwise
-	 */
-	void setIsApplicationWindowActive(bool active);
-
 	/**
 	 * Called when an authenticated connection to the server is established.
 	 */
@@ -285,7 +288,6 @@ private slots:
 	 */
 	void onConnectionError(QXmppClient::Error error);
 
-
 private:
 	/**
 	 * Starts a pending (enqueued) task (e.g. a password change) if the variable (e.g. a
@@ -302,20 +304,19 @@ private:
 	LogHandler *m_logger;
 	bool m_enableLogging;
 
-	RegistrationManager *m_registrationManager;
-	RosterManager *m_rosterManager;
-	MessageHandler *m_messageHandler;
-	DiscoveryManager *m_discoveryManager;
-	VCardManager *m_vCardManager;
-	UploadManager *m_uploadManager;
-	DownloadManager *m_downloadManager;
-	VersionManager *m_versionManager;
+	RegistrationManager *const m_registrationManager;
+	VCardManager *const m_vCardManager;
+	RosterManager *const m_rosterManager;
+	MessageHandler *const m_messageHandler;
+	DiscoveryManager *const m_discoveryManager;
+	UploadManager *const m_uploadManager;
+	DownloadManager *const m_downloadManager;
+	VersionManager *const m_versionManager;
 
 	QList<std::function<void ()>> m_pendingTasks;
 	uint m_activeTasks = 0;
 
 	bool m_isFirstLoginAfterStart = true;
-	bool m_isApplicationWindowActive;
 	bool m_isReconnecting = false;
 	bool m_isDisconnecting = false;
 	QXmppConfiguration m_configToBeUsedOnNextConnect;
