@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -32,31 +32,29 @@
 // QXmpp
 #include <QXmppDiscoveryManager.h>
 #include <QXmppDiscoveryIq.h>
-// Kaidan
-#include "Globals.h"
 
 DiscoveryManager::DiscoveryManager(QXmppClient *client, QObject *parent)
-	: QObject(parent), client(client), manager(client->findExtension<QXmppDiscoveryManager>())
+	: QObject(parent), m_client(client), m_manager(client->findExtension<QXmppDiscoveryManager>())
 {
 	// we're a normal client (not a server, gateway, server component, etc.)
-	manager->setClientCategory("client");
-	manager->setClientName(APPLICATION_DISPLAY_NAME);
+	m_manager->setClientCategory("client");
+	m_manager->setClientName(APPLICATION_DISPLAY_NAME);
 #if defined Q_OS_ANDROID || defined UBUNTU_TOUCH
 	// on Ubuntu Touch and Android we're always a mobile client
-	manager->setClientType("phone");
+	m_manager->setClientType("phone");
 #else
 	// Plasma Mobile packages won't differ from desktop builds, so we need to check the mobile
 	// variable on runtime.
 	if (!qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_MOBILE"))
-		manager->setClientType("phone");
+		m_manager->setClientType("phone");
 	else
-		manager->setClientType("pc");
+		m_manager->setClientType("pc");
 #endif
 
 	connect(client, &QXmppClient::connected, this, &DiscoveryManager::handleConnection);
-	connect(manager, &QXmppDiscoveryManager::infoReceived,
+	connect(m_manager, &QXmppDiscoveryManager::infoReceived,
 	        this, &DiscoveryManager::handleInfo);
-	connect(manager, &QXmppDiscoveryManager::itemsReceived,
+	connect(m_manager, &QXmppDiscoveryManager::itemsReceived,
 	        this, &DiscoveryManager::handleItems);
 }
 
@@ -67,8 +65,8 @@ DiscoveryManager::~DiscoveryManager()
 void DiscoveryManager::handleConnection()
 {
 	// request disco info & items from the server
-	manager->requestInfo(client->configuration().domain());
-	manager->requestItems(client->configuration().domain());
+	m_manager->requestInfo(m_client->configuration().domain());
+	m_manager->requestItems(m_client->configuration().domain());
 }
 
 void DiscoveryManager::handleInfo(const QXmppDiscoveryIq&)
@@ -81,8 +79,8 @@ void DiscoveryManager::handleItems(const QXmppDiscoveryIq &iq)
 	// request info from all items
 	const QList<QXmppDiscoveryIq::Item> items = iq.items();
 	for (const QXmppDiscoveryIq::Item &item : items) {
-		if (item.jid() == client->configuration().domain())
+		if (item.jid() == m_client->configuration().domain())
 			continue;
-		manager->requestInfo(item.jid());
+		m_manager->requestInfo(item.jid());
 	}
 }
