@@ -32,26 +32,21 @@
 
 // Qt
 #include <QDir>
-#include <QNetworkAccessManager>
 #include <QNetworkReply>
-#include <QNetworkRequest>
 #include <QStandardPaths>
 // Kaidan
 #include "Kaidan.h"
 #include "MessageModel.h"
 #include "TransferCache.h"
 
-DownloadManager::DownloadManager(TransferCache *transferCache, MessageModel *model, QObject *parent)
+DownloadManager::DownloadManager(TransferCache *transferCache, QObject *parent)
 	: QObject(parent),
 	  m_netMngr(new QNetworkAccessManager(this)),
-	  m_transferCache(transferCache),
-	  m_model(model)
+	  m_transferCache(transferCache)
 {
 	connect(this, &DownloadManager::startDownloadRequested,
 	        this, &DownloadManager::startDownload);
 	connect(this, &DownloadManager::abortDownloadRequested, this, &DownloadManager::abortDownload);
-
-	connect(Kaidan::instance(), &Kaidan::downloadMedia, this, &DownloadManager::startDownload);
 }
 
 DownloadManager::~DownloadManager()
@@ -76,7 +71,7 @@ void DownloadManager::startDownload(const QString &msgId, const QString &url)
 
 	connect(dl, &DownloadJob::finished, this, [=]() {
 		const QString &mediaLocation = dl->downloadLocation();
-		emit m_model->updateMessageRequested(msgId, [=] (Message &msg) {
+		emit MessageModel::instance()->updateMessageRequested(msgId, [=](Message &msg) {
 			msg.setMediaLocation(mediaLocation);
 		});
 
