@@ -32,11 +32,13 @@
 
 // Qt
 #include <QGuiApplication>
+#include <QSettings>
 #include <QThread>
 #include <QTimer>
 // QXmpp
 #include "qxmpp-exts/QXmppUri.h"
 // Kaidan
+#include "AccountManager.h"
 #include "AvatarFileStorage.h"
 #include "CredentialsValidator.h"
 #include "Database.h"
@@ -47,7 +49,7 @@
 
 Kaidan *Kaidan::s_instance;
 
-Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
+Kaidan::Kaidan(bool enableLogging, QObject *parent)
 	: QObject(parent)
 {
 	Q_ASSERT(!s_instance);
@@ -57,10 +59,8 @@ Kaidan::Kaidan(QGuiApplication *app, bool enableLogging, QObject *parent)
 	initializeCaches();
 	initializeClientWorker(enableLogging);
 
-	connect(app, &QGuiApplication::applicationStateChanged, this, &Kaidan::handleApplicationStateChanged);
-
 	// Log out of the server when the application window is closed.
-	connect(app, &QGuiApplication::lastWindowClosed, this, [this]() {
+	connect(qGuiApp, &QGuiApplication::lastWindowClosed, this, [this]() {
 		emit logOutRequested(true);
 	});
 }
@@ -72,6 +72,16 @@ Kaidan::~Kaidan()
 	s_instance = nullptr;
 }
 
+QSize Kaidan::applicationWindowSize() const
+{
+	return m_caches->settings->value(KAIDAN_SETTINGS_WINDOW_SIZE).toSize();
+}
+
+void Kaidan::storeApplicationWindowSize(const QSize &size) const
+{
+	m_caches->settings->setValue(KAIDAN_SETTINGS_WINDOW_SIZE, size);
+}
+
 void Kaidan::logIn()
 {
 	emit logInRequested();
@@ -87,14 +97,6 @@ void Kaidan::logOut()
 	emit logOutRequested();
 }
 
-void Kaidan::handleApplicationStateChanged(Qt::ApplicationState applicationState)
-{
-	if (applicationState == Qt::ApplicationActive)
-		emit applicationWindowActiveChanged(true);
-	else
-		emit applicationWindowActiveChanged(false);
-}
-
 void Kaidan::setConnectionState(Enums::ConnectionState connectionState)
 {
 	if (m_connectionState != connectionState) {
@@ -208,7 +210,7 @@ void Kaidan::initializeDatabase()
 
 void Kaidan::initializeCaches()
 {
-	m_caches = new ClientWorker::Caches(m_rosterDb, m_msgDb, this);
+	m_caches = new ClientWorker::Caches(this);
 
 	// Connect the avatar changed signal of the avatarStorage with the NOTIFY signal
 	// of the Q_PROPERTY for the avatar storage (so all avatars are updated in QML)
@@ -225,33 +227,20 @@ void Kaidan::initializeClientWorker(bool enableLogging)
 
 	connect(AccountManager::instance(), &AccountManager::credentialsNeeded, this, &Kaidan::credentialsNeeded);
 
-	connect(m_client, &ClientWorker::loggedInWithNewCredentials, this, &Kaidan::loggedInWithNewCredentials);
+	connect(m_client, &ClientWorker::loggedInWithNewCredentials, this, &Kaidan::openChatViewRequested);
 	connect(m_client, &ClientWorker::connectionStateChanged, this, &Kaidan::setConnectionState);
 	connect(m_client, &ClientWorker::connectionErrorChanged, this, &Kaidan::setConnectionError);
-	connect(m_client, &ClientWorker::showMessageNotificationRequested, this, [](const QString &senderJid, const QString &senderName, const QString &message) {
-		Notifications::sendMessageNotification(senderJid, senderName, message);
-	});
 
 	connect(m_cltThrd, &QThread::started, m_client, &ClientWorker::initialize);
 	m_cltThrd->start();
 }
 
-ClientWorker *Kaidan::client() const
-{
-	return m_client;
-}
-
-RosterDb *Kaidan::rosterDb() const
-{
-	return m_rosterDb;
-}
-
-MessageDb *Kaidan::messageDb() const
-{
-	return m_msgDb;
-}
-
 Kaidan *Kaidan::instance()
 {
 	return s_instance;
 }
+
+Database *Kaidan::database() const
+{
+	return m_database;
+}
