@@ -32,15 +32,15 @@
 
 // Qt
 #include <QObject>
-#include <QString>
 // Kaidan
 #include "ClientWorker.h"
-#include "RegistrationDataFormModel.h"
 
-class QGuiApplication;
+class QSize;
 class Database;
+class DataFormModel;
+class RosterDb;
+class MessageDb;
 class QXmppClient;
-class QXmppVersionIq;
 
 /**
  * @class Kaidan Kaidan's Back-End Class
@@ -55,8 +55,7 @@ class Kaidan : public QObject
 {
 	Q_OBJECT
 
-	Q_PROPERTY(RosterModel* rosterModel READ rosterModel CONSTANT)
-	Q_PROPERTY(MessageModel* messageModel READ messageModel CONSTANT)
+	Q_PROPERTY(ClientWorker* client READ client CONSTANT)
 	Q_PROPERTY(AvatarFileStorage* avatarStorage READ avatarStorage NOTIFY avatarStorageChanged)
 	Q_PROPERTY(PresenceCache* presenceCache READ presenceCache CONSTANT)
 	Q_PROPERTY(TransferCache* transferCache READ transferCache CONSTANT)
@@ -82,13 +81,27 @@ public:
 	/**
 	 * Constructs Kaidan's main object and initializes all components / threads.
 	 *
-	 * @param app GUI application object for managing Kaidan's GUI
 	 * @param enableLogging true to enable logging, otherwise false
 	 */
-	Kaidan(QGuiApplication *app, bool enableLogging = true, QObject *parent = nullptr);
+	Kaidan(bool enableLogging = true, QObject *parent = nullptr);
 
 	~Kaidan();
 
+	/**
+	 * Returns the application window size stored in the settings file.
+	 *
+	 * @return the application window size
+	 */
+	Q_INVOKABLE QSize applicationWindowSize() const;
+
+	/**
+	 * Stores the application window size in the settings file to be restored
+	 * on the next application start.
+	 *
+	 * @param size size of the application window
+	 */
+	Q_INVOKABLE void storeApplicationWindowSize(const QSize &size) const;
+
 	/**
 	 * Connects to the XMPP server and logs in to it.
 	 *
@@ -132,14 +145,9 @@ public:
 	 */
 	PasswordVisibility passwordVisibility() const;
 
-	RosterModel* rosterModel() const
+	ClientWorker *client() const
 	{
-		return m_caches->rosterModel;
-	}
-
-	MessageModel* messageModel() const
-	{
-		return m_caches->msgModel;
+		return m_client;
 	}
 
 	AvatarFileStorage* avatarStorage() const
@@ -162,16 +170,17 @@ public:
 		return m_caches->serverFeaturesCache;
 	}
 
+	VCardCache *vCardCache() const
+	{
+		return m_caches->vCardCache;
+	}
+
 	QSettings* settings() const
 	{
 		return m_caches->settings;
 	}
 
-	ClientWorker *client() const;
-
-	RosterDb *rosterDb() const;
-
-	MessageDb *messageDb() const;
+	Database *database() const;
 
 	/**
 	 * Adds XMPP URI to open as soon as possible
@@ -203,21 +212,6 @@ public:
 	Q_INVOKABLE quint8 logInByUri(const QString &uri);
 
 signals:
-	/**
-	 * Emitted when the application window becomes active or inactive.
-	 *
-	 * The application window is active when it is in the foreground and focused.
-	 *
-	 * @param active true if the application window becomes active, false otherwise
-	 */
-	void applicationWindowActiveChanged(bool active);
-
-	/**
-	 * Emitted to request a registration form from the server which is set as the
-	 * currently used JID.
-	 */
-	void registrationFormRequested();
-
 	/**
 	 * Emitted when a data form for registration is received from the server.
 	 *
@@ -226,9 +220,18 @@ signals:
 	void registrationFormReceived(DataFormModel *dataFormModel);
 
 	/**
-	 * Emitted to send a completed data form for registration.
+	 * Emitted when an out-of-band URL for registration is received from the
+	 * server.
+	 *
+	 * @param outOfBandUrl URL used for out-of-band registration
 	 */
-	void sendRegistrationForm();
+	void registrationOutOfBandUrlReceived(const QString &outOfBandUrl);
+
+	/**
+	 * Emitted to request a registration form from the server which is set as the
+	 * currently used JID.
+	 */
+	void registrationFormRequested();
 
 	/**
 	 * Emitted when the account registration failed.
@@ -285,11 +288,17 @@ signals:
 	void raiseWindowRequested();
 
 	/**
-	 * Opens the chat page for a given JID.
-	 *
-	 * @param chatJid JID of the chat for which the chat page is opened
+	 * Opens the view with the roster and empty chat page.
 	 */
-	void openChatPageRequested(const QString chatJid);
+	void openChatViewRequested();
+
+	/**
+	 * Opens the chat page for a given chat.
+	 *
+	 * @param accountJid JID of the account for that the chat page is opened
+	 * @param chatJid JID of the chat for that the chat page is opened
+	 */
+	void openChatPageRequested(const QString &accountJid, const QString &chatJid);
 
 	/**
 	 * Emitted when the removal state of the password on the account transfer page changed.
@@ -301,24 +310,6 @@ signals:
 	 */
 	void passiveNotificationRequested(QString text);
 
-	/**
-	 * Emitted, whan a subscription request was received
-	 */
-	void subscriptionRequestReceived(QString from, QString msg);
-
-	/**
-	 * Incoming subscription request was accepted or declined by the user
-	 */
-	void subscriptionRequestAnswered(QString jid, bool accepted);
-
-	/**
-	 * Request vCard of any JID
-	 *
-	 * Is required when the avatar (or other information) of a JID are
-	 * requested and the JID is not in the roster.
-	 */
-	void vCardRequested(const QString &jid);
-
 	/**
 	 * XMPP URI received
 	 *
@@ -327,72 +318,9 @@ signals:
 	void xmppUriReceived(QString uri);
 
 	/**
-	 * The upload progress of a file upload has changed
+	 * Emitted when changing of the user's password finished succfessully.
 	 */
-	void uploadProgressMade(QString msgId, quint64 sent, quint64 total);
-
-	/**
-	 * Send a text message to any JID
-	 *
-	 * Currently only contacts are displayed on the RosterPage (there is no
-	 * way to view a list of all chats -> for contacts and non-contacts), so
-	 * you should only send messages to JIDs from your roster, otherwise you
-	 * won't be able to see the message history.
-	 */
-	void sendMessage(QString jid, QString message, bool isSpoiler, QString spoilerHint);
-
-	/**
-	 * Correct the last message
-	 *
-	 */
-	void correctMessage(const QString &msgId, const QString &message);
-
-	/**
-	 * Upload and send file
-	 */
-	void sendFile(const QString &jid, const QUrl &fileUrl, const QString &body);
-
-	/**
-	 * Add a contact to your roster
-	 *
-	 * @param nick A simple nick name for the new contact, which should be
-	 *             used to display in the roster.
-	 */
-	void addContact(QString jid, QString nick, QString msg);
-
-	/**
-	 * Remove a contact from your roster
-	 *
-	 * Only the JID is needed.
-	 */
-	void removeContact(QString jid);
-
-	/**
-	 * Change a contact's name
-	 */
-	void renameContact(const QString &jid, const QString &newContactName);
-
-	/**
-	 * Downloads an attached media file of a message
-	 *
-	 * @param msgId The message
-	 * @param url the media url from the message
-	 */
-	void downloadMedia(QString msgId, QString url);
-
-	/**
-	 * Changes the user's display name.
-	 *
-	 * @param displayName new name that is shown to contacts
-	 */
-	void changeDisplayName(const QString &displayName);
-
-	/**
-	 * Changes the user's password on the server
-	 *
-	 * @param newPassword The new password
-	 */
-	void changePassword(const QString &newPassword);
+	void passwordChangeSucceeded();
 
 	/**
 	 * Emitted when changing the user's password failed.
@@ -416,25 +344,7 @@ signals:
 	 */
 	void deleteAccountFromClient();
 
-	/**
-	  * Requests fetching the version information of all resources of the given
-	  * bare JID
-	  */
-	void requestClientVersions(const QString &bareJid, const QString &resource = {});
-
-	/**
-	  * Emitted when a client version information was received
-	  */
-	void clientVersionReceived(const QXmppVersionIq &versionIq);
-
 public slots:
-	/**
-	 * Handles a changed application state and emits whether the application window is active.
-	 *
-	 * @param applicationState state of the GUI application
-	 */
-	void handleApplicationStateChanged(Qt::ApplicationState applicationState);
-
 	/**
 	 * Set current connection state
 	 */
@@ -494,7 +404,7 @@ private:
 	ClientWorker *m_client;
 
 	QString m_openUriCache;
-	ConnectionState m_connectionState = ConnectionState::StateDisconnected;
+	Enums::ConnectionState m_connectionState = Enums::ConnectionState::StateDisconnected;
 	ClientWorker::ConnectionError m_connectionError = ClientWorker::NoError;
 
 	static Kaidan *s_instance;
