@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -31,9 +31,9 @@
 #include "MediaUtils.h"
 
 #include <QFileInfo>
-#include <QUrl>
 #include <QRegularExpression>
 #include <QTime>
+#include <QUrl>
 
 static QList<QMimeType> mimeTypes(const QList<QMimeType> &mimeTypes, const QString &parent);
 
@@ -245,6 +245,27 @@ QString MediaUtils::iconName(const QUrl &url)
 	return iconName(url.fileName());
 }
 
+QString MediaUtils::mediaTypeName(Enums::MessageType mediaType)
+{
+	switch (mediaType) {
+	case Enums::MessageType::MessageAudio:
+		return tr("Audio");
+	case Enums::MessageType::MessageDocument:
+		return tr("Document");
+	case Enums::MessageType::MessageGeoLocation:
+		return tr("Location");
+	case Enums::MessageType::MessageImage:
+		return tr("Image");
+	case Enums::MessageType::MessageVideo:
+		return tr("Video");
+	case Enums::MessageType::MessageFile:
+	case Enums::MessageType::MessageText:
+	case Enums::MessageType::MessageUnknown:
+		return tr("File");
+	}
+	return {};
+}
+
 QString MediaUtils::newMediaLabel(Enums::MessageType hint)
 {
 	switch (hint) {
@@ -275,9 +296,9 @@ QString MediaUtils::newMediaIconName(Enums::MessageType hint)
 	case Enums::MessageType::MessageVideo:
 		return QStringLiteral("camera-video-symbolic");
 	case Enums::MessageType::MessageAudio:
-		return QStringLiteral("microphone");
+		return QStringLiteral("audio-input-microphone-symbolic");
 	case Enums::MessageType::MessageGeoLocation:
-		return QStringLiteral("gps");
+		return QStringLiteral("mark-location-symbolic");
 	case Enums::MessageType::MessageText:
 	case Enums::MessageType::MessageFile:
 	case Enums::MessageType::MessageDocument:
