@@ -137,3 +137,15 @@ private:
 	 */
 	QString m_errorText;
 };
+
+Q_DECLARE_METATYPE(Message)
+
+enum class MessageOrigin : quint8 {
+	Stream,
+	UserInput,
+	MamInitial,
+	MamCatchUp,
+	MamBacklog,
+};
+
+Q_DECLARE_METATYPE(MessageOrigin);
