@@ -36,10 +36,13 @@
 #include <QSqlField>
 #include <QSqlQuery>
 #include <QSqlRecord>
+#include <QStringBuilder>
 // Kaidan
 #include "Globals.h"
 #include "Utils.h"
 
+#define CHECK_MESSAGE_EXISTS_DEPTH_LIMIT "20"
+
 MessageDb *MessageDb::s_instance = nullptr;
 
 MessageDb::MessageDb(QObject *parent)
@@ -53,6 +56,8 @@ MessageDb::MessageDb(QObject *parent)
 
 	connect(this, &MessageDb::fetchPendingMessagesRequested,
 	        this, &MessageDb::fetchPendingMessages);
+
+	connect(this, &MessageDb::fetchLastMessageStampRequested, this, &MessageDb::fetchLastMessageStamp);
 }
 
 MessageDb::~MessageDb()
@@ -86,6 +91,8 @@ void MessageDb::parseMessagesFromQuery(QSqlQuery &query, QVector<Message> &msgs)
 	int idxIsSpoiler = rec.indexOf("isSpoiler");
 	int idxErrorText = rec.indexOf("errorText");
 	int idxReplaceId = rec.indexOf("replaceId");
+	int idxOriginId = rec.indexOf("originId");
+	int idxStanza = rec.indexOf("stanzaId");
 
 	while (query.next()) {
 		Message msg;
@@ -111,6 +118,8 @@ void MessageDb::parseMessagesFromQuery(QSqlQuery &query, QVector<Message> &msgs)
 		msg.setErrorText(query.value(idxErrorText).toString());
 		msg.setIsSpoiler(query.value(idxIsSpoiler).toBool());
 		msg.setReplaceId(query.value(idxReplaceId).toString());
+		msg.setOriginId(query.value(idxOriginId).toString());
+		msg.setStanzaId(query.value(idxStanza).toString());
 		msg.setReceiptRequested(true);	//this is useful with resending pending messages
 		msgs << msg;
 	}
@@ -171,6 +180,10 @@ QSqlRecord MessageDb::createUpdateRecord(const Message &oldMsg, const Message &n
 		rec.append(Utils::createSqlField("isSpoiler", newMsg.isSpoiler()));
 	if (oldMsg.replaceId() != newMsg.replaceId())
 		rec.append(Utils::createSqlField("replaceId", newMsg.replaceId()));
+	if (oldMsg.originId() != newMsg.originId())
+		rec.append(Utils::createSqlField("originId", newMsg.originId()));
+	if (oldMsg.stanzaId() != newMsg.stanzaId())
+		rec.append(Utils::createSqlField("stanzaId", newMsg.stanzaId()));
 
 	return rec;
 }
@@ -230,8 +243,45 @@ Message MessageDb::fetchLastMessage(const QString &user1, const QString &user2)
 	return {};
 }
 
-void MessageDb::addMessage(const Message &msg)
+void MessageDb::fetchLastMessageStamp()
 {
+	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
+	query.setForwardOnly(true);
+
+	Utils::execQuery(query, "SELECT timestamp FROM Messages ORDER BY timestamp DESC LIMIT 1");
+
+	QDateTime stamp;
+	while (query.next()) {
+		stamp = QDateTime::fromString(
+			query.value(query.record().indexOf("timestamp")).toString(),
+			Qt::ISODate
+		);
+	}
+
+	emit lastMessageStampFetched(stamp);
+}
+
+void MessageDb::addMessage(const Message &msg, MessageOrigin origin)
+{
+	// deduplication
+	switch (origin) {
+	case MessageOrigin::MamBacklog:
+	case MessageOrigin::MamCatchUp:
+	case MessageOrigin::Stream:
+		if (checkMessageExists(msg)) {
+			// message deduplicated (messageAdded() signal is not emitted)
+			return;
+		}
+		break;
+	case MessageOrigin::MamInitial:
+	case MessageOrigin::UserInput:
+		// no deduplication required
+		break;
+	}
+
+	// to speed up the whole process emit signal first and do the actual insert after that
+	emit messageAdded(msg, origin);
+
 	QSqlDatabase db = QSqlDatabase::database(DB_CONNECTION);
 
 	QSqlRecord record = db.record(DB_TABLE_MESSAGES);
@@ -252,6 +302,8 @@ void MessageDb::addMessage(const Message &msg)
 	record.setValue("mediaLastModified", msg.mediaLastModified().toMSecsSinceEpoch());
 	record.setValue("errorText", msg.errorText());
 	record.setValue("replaceId", msg.replaceId());
+	record.setValue("originId", msg.originId());
+	record.setValue("stanzaId", msg.stanzaId());
 
 	QSqlQuery query(db);
 	Utils::execQuery(query, db.driver()->sqlStatement(
@@ -262,17 +314,7 @@ void MessageDb::addMessage(const Message &msg)
 	));
 }
 
-void MessageDb::removeMessage(const QString &id)
-{
-	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
-	Utils::execQuery(
-		query,
-		"DELETE FROM " DB_TABLE_MESSAGES " WHERE id = ?",
-		QVector<QVariant>() << id
-	);
-}
-
-void MessageDb::removeAllMessages()
+void MessageDb::removeMessages(const QString &, const QString &)
 {
 	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
 	Utils::execQuery(query, "DELETE FROM " DB_TABLE_MESSAGES);
@@ -336,6 +378,54 @@ void MessageDb::updateMessageRecord(const QString &id,
 	);
 }
 
+bool MessageDb::checkMessageExists(const Message &message)
+{
+	QMap<QString, QVariant> bindValues = {
+		{ ":to", message.to() },
+		{ ":from", message.from() },
+	};
+
+	// Check which IDs to check
+	QStringList idChecks;
+	if (!message.stanzaId().isEmpty()) {
+		idChecks << QStringLiteral("stanzaId = :stanzaId");
+		bindValues.insert(QStringLiteral(":stanzaId"), message.stanzaId());
+	}
+	// only check origin IDs if the message was possibly sent by us (since
+	// Kaidan uses random suffixes in the resource, we can't check the resource)
+	if (message.sentByMe() && !message.originId().isEmpty()) {
+		idChecks << QStringLiteral("originId = :originId");
+		bindValues.insert(QStringLiteral(":originId"), message.stanzaId());
+	}
+	if (!message.id().isEmpty()) {
+		idChecks << QStringLiteral("id = :id");
+		bindValues.insert(QStringLiteral(":id"), message.stanzaId());
+	}
+
+	if (idChecks.isEmpty()) {
+		// if we have no checks because of missing IDs, report that the message
+		// does not exist
+		return false;
+	}
+
+	const QString idConditionSql = idChecks.join(u" OR ");
+	const QString querySql =
+		QStringLiteral("SELECT COUNT(*) FROM " DB_TABLE_MESSAGES " "
+			       "WHERE (author = :from AND recipient = :to AND (") %
+		idConditionSql %
+		QStringLiteral(")) ORDER BY timestamp DESC LIMIT " CHECK_MESSAGE_EXISTS_DEPTH_LIMIT);
+
+	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
+	query.setForwardOnly(true);
+	Utils::execQuery(query, querySql, bindValues);
+
+	int count = 0;
+	if (query.next()) {
+		count = query.value(0).toInt();
+	}
+	return count > 0;
+}
+
 void MessageDb::fetchPendingMessages(const QString& userJid)
 {
 	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
