@@ -80,6 +80,10 @@ signals:
 	 *  Emitted to fetch pending messages.
 	 */
 	void fetchPendingMessagesRequested(const QString &userJid);
+	void fetchLastMessageStampRequested();
+
+	void updateMessageRequested(const QString &id, const std::function<void (Message &)> &updateMsg);
+	void removeAllMessagesRequested();
 
 	/**
 	 * Emitted when new messages have been fetched
@@ -91,6 +95,13 @@ signals:
 	 */
 	void pendingMessagesFetched(const QVector<Message> &messages);
 
+	/**
+	 * Emitted when the latest message stamp was fetched
+	 */
+	void lastMessageStampFetched(const QDateTime &stamp);
+
+	void messageAdded(const Message &msg, MessageOrigin origin);
+
 public slots:
 	/**
 	 * @brief Fetches more entries from the database and emits messagesFetched() with
@@ -116,20 +127,23 @@ public slots:
 	 */
 	Message fetchLastMessage(const QString &user1, const QString &user2);
 
+	/**
+	 * Fetch the latest message stamp
+	 */
+	void fetchLastMessageStamp();
+
 	/**
 	 * Adds a message to the database.
 	 */
-	void addMessage(const Message &msg);
+	void addMessage(const Message &msg, MessageOrigin origin);
 
 	/**
-	 * Deletes a message from the database.
+	 * Removes all messages of an account or an account's chat.
+	 *
+	 * @param accountJid JID of the account whose messages are being removed
+	 * @param chatJid JID of the chat whose messages are being removed (optional)
 	 */
-	void removeMessage(const QString &id);
-
-	/**
-	 * Removes all messages from the database.
-	 */
-	void removeAllMessages();
+	void removeMessages(const QString &accountJid, const QString &chatJid = {});
 
 	/**
 	 * Loads a message, runs the update lambda and writes it to the DB again.
@@ -148,6 +162,12 @@ public slots:
 	void updateMessageRecord(const QString &id,
 	                         const QSqlRecord &updateRecord);
 
+private slots:
+	/**
+	 * Checks whether a message already exists in the database
+	 */
+	bool checkMessageExists(const Message &message);
+
 private:
 	static MessageDb *s_instance;
 };
