@@ -30,12 +30,9 @@
 
 #include "MessageHandler.h"
 // Qt
-#include <QDateTime>
-#include <QMimeDatabase>
 #include <QUrl>
 // QXmpp
 #include <QXmppCarbonManager.h>
-#include <QXmppClient.h>
 #include <QXmppDiscoveryManager.h>
 #include <QXmppRosterManager.h>
 #include <QXmppUtils.h>
@@ -43,27 +40,45 @@
 #include "ClientWorker.h"
 #include "Globals.h"
 #include "Kaidan.h"
+#include "Database.h"
+#include "Message.h"
+#include "MessageDb.h"
 #include "MessageModel.h"
 #include "MediaUtils.h"
 
-MessageHandler::MessageHandler(ClientWorker *clientWorker, QXmppClient *client, MessageModel *model, QObject *parent)
+// Number of messages fetched at once when loading MAM backlog
+constexpr int MAM_BACKLOG_FETCH_COUNT = 40;
+
+MessageHandler::MessageHandler(ClientWorker *clientWorker, QXmppClient *client, QObject *parent)
 	: QObject(parent),
 	  m_clientWorker(clientWorker),
 	  m_client(client),
-	  m_model(model)
+	  m_carbonManager(new QXmppCarbonManager),
+	  m_mamManager(new QXmppMamManager)
 {
-	connect(client, &QXmppClient::messageReceived, this, &MessageHandler::handleMessage);
-	connect(Kaidan::instance(), &Kaidan::sendMessage, this, &MessageHandler::sendMessage);
-	connect(model, &MessageModel::sendCorrectedMessageRequested, this, &MessageHandler::sendCorrectedMessage);
-
-	client->addExtension(&m_receiptManager);
-	connect(&m_receiptManager, &QXmppMessageReceiptManager::messageDelivered,
-		this, [=] (const QString&, const QString &id) {
-		emit model->setMessageDeliveryStateRequested(id, Enums::DeliveryState::Delivered);
+	connect(client, &QXmppClient::messageReceived, this, [=](const QXmppMessage &msg) {
+		handleMessage(msg, MessageOrigin::Stream);
 	});
+	connect(this, &MessageHandler::sendMessageRequested, this, &MessageHandler::sendMessage);
+	connect(MessageModel::instance(), &MessageModel::sendCorrectedMessageRequested,
+	        this, &MessageHandler::sendCorrectedMessage);
+	connect(MessageModel::instance(), &MessageModel::sendChatStateRequested,
+	        this, &MessageHandler::sendChatState);
 
-	m_carbonManager = new QXmppCarbonManager();
-	client->addExtension(m_carbonManager);
+	connect(client, &QXmppClient::connected, this, &MessageHandler::handleConnected);
+	connect(client, &QXmppClient::disconnected, this, &MessageHandler::handleDisonnected);
+	connect(client->findExtension<QXmppRosterManager>(), &QXmppRosterManager::rosterReceived,
+	        this, &MessageHandler::handleRosterReceived);
+	connect(MessageDb::instance(), &MessageDb::lastMessageStampFetched,
+	        this, &MessageHandler::handleLastMessageStampFetched);
+
+	connect(&m_receiptManager, &QXmppMessageReceiptManager::messageDelivered,
+		this, [=](const QString &, const QString &id) {
+		emit MessageModel::instance()->updateMessageRequested(id, [](Message &msg) {
+			msg.setDeliveryState(Enums::DeliveryState::Delivered);
+			msg.setErrorText({});
+		});
+	});
 
 	// messages sent to our account (forwarded from another client)
 	connect(m_carbonManager, &QXmppCarbonManager::messageReceived,
@@ -72,6 +87,15 @@ MessageHandler::MessageHandler(ClientWorker *clientWorker, QXmppClient *client,
 	connect(m_carbonManager, &QXmppCarbonManager::messageSent,
 	        client, &QXmppClient::messageReceived);
 
+	connect(m_mamManager, &QXmppMamManager::archivedMessageReceived, this, &MessageHandler::handleArchiveMessage);
+	connect(m_mamManager, &QXmppMamManager::resultsRecieved, this, &MessageHandler::handleArchiveResults);
+
+	connect(this, &MessageHandler::retrieveBacklogMessagesRequested, this, &MessageHandler::retrieveBacklogMessages);
+
+	client->addExtension(&m_receiptManager);
+	client->addExtension(m_carbonManager);
+	client->addExtension(m_mamManager);
+
 	// carbons discovery
 	auto *discoveryManager = client->findExtension<QXmppDiscoveryManager>();
 	if (!discoveryManager)
@@ -80,22 +104,63 @@ MessageHandler::MessageHandler(ClientWorker *clientWorker, QXmppClient *client,
 	connect(discoveryManager, &QXmppDiscoveryManager::infoReceived,
 	        this, &MessageHandler::handleDiscoInfo);
 
-	connect(model, &MessageModel::pendingMessagesFetched,
+	connect(MessageModel::instance(), &MessageModel::pendingMessagesFetched,
 			this, &MessageHandler::handlePendingMessages);
+
+	// get last message stamp to retrieve all new messages from the server since then
+	emit MessageDb::instance()->fetchLastMessageStampRequested();
 }
 
 MessageHandler::~MessageHandler()
 {
 	delete m_carbonManager;
+	delete m_mamManager;
 }
 
-void MessageHandler::handleMessage(const QXmppMessage &msg)
+void MessageHandler::handleRosterReceived()
+{
+	// retrieve initial messages for each contact, if there is no last message locally
+	if (m_lastMessageLoaded && m_lastMessageStamp.isNull())
+		retrieveInitialMessages();
+}
+
+void MessageHandler::handleLastMessageStampFetched(const QDateTime &stamp)
+{
+	m_lastMessageStamp = stamp;
+	m_lastMessageLoaded = true;
+
+	// this is for the case that loading the last message took longer than connecting to
+	// the server:
+
+	// if already connected directly retrieve messages
+	if (m_client->isConnected()) {
+		// if there are no messages at all, load initial history,
+		// otherwise load all missed messages since last online.
+		if (stamp.isNull()) {
+			// only start if roster was received already
+			if (m_client->findExtension<QXmppRosterManager>()->isRosterReceived())
+				retrieveInitialMessages();
+		} else {
+			retrieveCatchUpMessages(stamp);
+		}
+	}
+}
+
+void MessageHandler::handleMessage(const QXmppMessage &msg, MessageOrigin origin)
 {
 	if (msg.type() == QXmppMessage::Error) {
-		emit m_model->setMessageDeliveryStateRequested(msg.id(), Enums::DeliveryState::Error, msg.error().text());
+		emit MessageModel::instance()->updateMessageRequested(msg.id(), [errorText { msg.error().text() }](Message &msg) {
+			msg.setDeliveryState(Enums::DeliveryState::Error);
+			msg.setErrorText(errorText);
+		});
 		return;
 	}
 
+	if (msg.state() != QXmppMessage::State::None) {
+		emit MessageModel::instance()->handleChatStateRequested(
+				QXmppUtils::jidToBareJid(msg.from()), msg.state());
+	}
+
 	if (msg.body().isEmpty() && msg.outOfBandUrl().isEmpty())
 		return;
 
@@ -111,6 +176,8 @@ void MessageHandler::handleMessage(const QXmppMessage &msg)
 	message.setIsSpoiler(msg.isSpoiler());
 	message.setSpoilerHint(msg.spoilerHint());
 	message.setOutOfBandUrl(msg.outOfBandUrl());
+	message.setStanzaId(msg.stanzaId());
+	message.setOriginId(msg.originId());
 
 	// check if message contains a link and also check out of band url
 	if (!parseMediaUri(message, msg.outOfBandUrl(), false)) {
@@ -129,36 +196,15 @@ void MessageHandler::handleMessage(const QXmppMessage &msg)
 	// save the message to the database
 	// in case of message correction, replace old message
 	if (msg.replaceId().isEmpty()) {
-		emit m_model->addMessageRequested(message);
+		emit MessageModel::instance()->addMessageRequested(message, origin);
 	} else {
 		message.setIsEdited(true);
 		message.setId(QString());
-		emit m_model->updateMessageRequested(msg.replaceId(), [=] (Message &m) {
+		emit MessageModel::instance()->updateMessageRequested(msg.replaceId(), [=](Message &m) {
 			// replace completely
 			m = message;
 		});
 	}
-
-	// Send a message notification
-
-	// The contact can differ if the message is really from a contact or just
-	// a forward of another of the user's clients.
-	QString contactJid = message.sentByMe() ? message.to() : message.from();
-	// resolve user-defined name of this JID
-	QString contactName = m_client->findExtension<QXmppRosterManager>()->getRosterEntry(contactJid).name();
-	if (contactName.isEmpty())
-		contactName = contactJid;
-
-	// Show a notification for the message in the following cases:
-	//  * The message was not sent by the user from another resource and received via Message Carbons.
-	//  * Notifications from the chat partner are not muted.
-	//  * The corresponding chat is not opened while the application window is active.
-	if (!message.sentByMe() &&
-			!Kaidan::instance()->notificationsMuted(contactJid) &&
-			(m_model->currentChatJid() != message.from() ||
-			 !m_clientWorker->isApplicationWindowActive())) {
-		emit m_clientWorker->showMessageNotificationRequested(contactJid, contactName, msg.body());
-	}
 }
 
 void MessageHandler::sendMessage(const QString& toJid,
@@ -171,6 +217,7 @@ void MessageHandler::sendMessage(const QString& toJid,
 	msg.setTo(toJid);
 	msg.setBody(body);
 	msg.setId(QXmppUtils::generateStanzaHash());
+	msg.setOriginId(msg.id());
 	msg.setReceiptRequested(true);
 	msg.setSentByMe(true);
 	msg.setMediaType(MessageType::MessageText); // text message without media
@@ -186,10 +233,18 @@ void MessageHandler::sendMessage(const QString& toJid,
 			break;
 	}
 
-	emit m_model->addMessageRequested(msg);
+	emit MessageModel::instance()->addMessageRequested(msg, MessageOrigin::UserInput);
 	sendPendingMessage(msg);
 }
 
+void MessageHandler::sendChatState(const QString &toJid, const QXmppMessage::State state)
+{
+	QXmppMessage message;
+	message.setTo(toJid);
+	message.setState(state);
+	m_client->sendPacket(message);
+}
+
 void MessageHandler::sendCorrectedMessage(const Message &msg)
 {
 	auto deliveryState = Enums::DeliveryState::Sent;
@@ -202,7 +257,7 @@ void MessageHandler::sendCorrectedMessage(const Message &msg)
 		deliveryState = Enums::DeliveryState::Error;
 	}
 
-	emit m_model->updateMessageRequested(msg.id(), [=] (Message &localMessage) {
+	emit MessageModel::instance()->updateMessageRequested(msg.id(), [=](Message &localMessage) {
 		localMessage.setDeliveryState(deliveryState);
 		localMessage.setErrorText(errorText);
 	});
@@ -217,6 +272,29 @@ void MessageHandler::handleDiscoInfo(const QXmppDiscoveryIq &info)
 		m_carbonManager->setCarbonsEnabled(true);
 }
 
+void MessageHandler::handleConnected()
+{
+	// retrieve missed messages, if the last saved message has been loaded and exists
+	if (m_lastMessageLoaded && !m_lastMessageStamp.isNull()) {
+		retrieveCatchUpMessages(m_lastMessageStamp);
+	}
+}
+
+void MessageHandler::handleDisonnected()
+{
+	// clear all running backlog queries
+	std::for_each(m_runningBacklogQueryIds.constKeyValueBegin(),
+				  m_runningBacklogQueryIds.constKeyValueEnd(),
+				  [=](const std::pair<QString, BacklogQueryState> &pair) {
+		emit MessageModel::instance()->mamBacklogRetrieved(
+				m_client->configuration().jidBare(), pair.second.chatJid, pair.second.lastTimestamp, false);
+	});
+	m_runningBacklogQueryIds.clear();
+
+	m_runningInitialMessageQueryIds.clear();
+	m_runnningCatchUpQueryId.clear();
+}
+
 void MessageHandler::sendPendingMessage(const Message &message)
 {
 	if (m_client->state() == QXmppClient::ConnectedState) {
@@ -232,8 +310,12 @@ void MessageHandler::sendPendingMessage(const Message &message)
 			success = m_client->sendPacket(message);
 		}
 
-		if (success)
-			emit m_model->setMessageDeliveryStateRequested(message.id(), Enums::DeliveryState::Sent);
+		if (success) {
+			emit MessageModel::instance()->updateMessageRequested(message.id(), [](Message &msg) {
+				msg.setDeliveryState(Enums::DeliveryState::Sent);
+				msg.setErrorText({});
+			});
+		}
 		// TODO this "true" from sendPacket doesn't yet mean the message was successfully sent
 
 		else {
@@ -244,7 +326,10 @@ void MessageHandler::sendPendingMessage(const Message &message)
 			// translation work in the UI, the tr() call of the passive
 			// notification must contain exactly the same string.
 			emit Kaidan::instance()->passiveNotificationRequested(tr("Message could not be sent."));
-			emit m_model->setMessageDeliveryStateRequested(message.id(), Enums::DeliveryState::Error, "Message could not be sent.");
+			emit MessageModel::instance()->updateMessageRequested(message.id(), [](Message &msg) {
+				msg.setDeliveryState(Enums::DeliveryState::Error);
+				msg.setErrorText(QStringLiteral("Message could not be sent."));
+			});
 		}
 	}
 }
@@ -295,3 +380,100 @@ void MessageHandler::handlePendingMessages(const QVector<Message> &messages)
 		sendPendingMessage(message);
 	}
 }
+
+void MessageHandler::handleArchiveMessage(const QString &queryId,
+                                          const QXmppMessage &message)
+{
+	if (queryId == m_runnningCatchUpQueryId) {
+		handleMessage(message, MessageOrigin::MamCatchUp);
+	} else if (m_runningInitialMessageQueryIds.contains(queryId)) {
+		// TODO: request other message if this message is empty (e.g. no body)
+		handleMessage(message, MessageOrigin::MamInitial);
+	} else if (m_runningBacklogQueryIds.contains(queryId)) {
+		handleMessage(message, MessageOrigin::MamBacklog);
+		// update last stamp
+		auto &lastTimestamp = m_runningBacklogQueryIds[queryId].lastTimestamp;
+		if (lastTimestamp > message.stamp()) {
+			lastTimestamp = message.stamp();
+		}
+	}
+}
+
+void MessageHandler::handleArchiveResults(const QString &queryId,
+                                          const QXmppResultSetReply &,
+                                          bool complete)
+{
+	if (queryId == m_runnningCatchUpQueryId) {
+		m_runnningCatchUpQueryId.clear();
+		emit Kaidan::instance()->database()->commitRequested();
+		return;
+	}
+
+	if (m_runningInitialMessageQueryIds.contains(queryId)) {
+		m_runningInitialMessageQueryIds.removeOne(queryId);
+
+		if (m_runningInitialMessageQueryIds.isEmpty()) {
+			emit Kaidan::instance()->database()->commitRequested();
+
+			// so this won't be triggered again on reconnect
+			m_lastMessageStamp = QDateTime::currentDateTimeUtc();
+		}
+		return;
+	}
+
+	if (m_runningBacklogQueryIds.contains(queryId)) {
+		const auto state = m_runningBacklogQueryIds.take(queryId);
+		emit MessageModel::instance()->mamBacklogRetrieved(m_client->configuration().jidBare(), state.chatJid, state.lastTimestamp, complete);
+	}
+}
+
+void MessageHandler::retrieveInitialMessages()
+{
+	QXmppResultSetQuery queryLimit;
+	// load only one message per user (the rest can be loaded when needed)
+	queryLimit.setMax(1);
+	// query last (newest) first
+	queryLimit.setBefore("");
+
+	const auto bareJids = m_client->findExtension<QXmppRosterManager>()->getRosterBareJids();
+	if (bareJids.isEmpty()) {
+		return;
+	}
+
+	m_runningInitialMessageQueryIds.clear();
+	m_runningInitialMessageQueryIds.reserve(bareJids.size());
+
+	for (const auto &jid : bareJids) {
+		m_runningInitialMessageQueryIds.push_back(m_mamManager->retrieveArchivedMessages(
+			QString(),
+			QString(),
+			jid,
+			QDateTime(),
+			QDateTime(),
+			queryLimit
+		));
+	}
+
+	emit Kaidan::instance()->database()->transactionRequested();
+}
+
+void MessageHandler::retrieveCatchUpMessages(const QDateTime &stamp)
+{
+	QXmppResultSetQuery queryLimit;
+	// no limit
+	queryLimit.setMax(-1);
+
+	m_runnningCatchUpQueryId = m_mamManager->retrieveArchivedMessages({}, {}, {}, stamp, {}, queryLimit);
+
+	emit Kaidan::instance()->database()->transactionRequested();
+}
+
+void MessageHandler::retrieveBacklogMessages(const QString &jid, const QDateTime &stamp)
+{
+	QXmppResultSetQuery queryLimit;
+	queryLimit.setBefore("");
+	queryLimit.setMax(MAM_BACKLOG_FETCH_COUNT);
+
+	const auto id = m_mamManager->retrieveArchivedMessages({}, {}, jid, {}, stamp, queryLimit);
+	m_runningBacklogQueryIds.insert(id, BacklogQueryState { jid, stamp });
+}
