@@ -33,16 +33,22 @@
 // Qt
 #include <QObject>
 // QXmpp
+#include <QXmppGlobal.h>
+#include <QXmppMamManager.h>
 #include <QXmppMessageReceiptManager.h>
 // Kaidan
 #include "Message.h"
+#include "Enums.h"
 
 class ClientWorker;
 class Kaidan;
-class MessageModel;
+
+class QMimeType;
+
 class QXmppMessage;
 class QXmppDiscoveryIq;
 class QXmppCarbonManager;
+class QXmppVersionIq;
 
 /**
  * @class MessageHandler Handler for incoming and outgoing messages.
@@ -52,19 +58,27 @@ class MessageHandler : public QObject
 	Q_OBJECT
 
 public:
-	MessageHandler(ClientWorker *clientWorker, QXmppClient *client, MessageModel *model, QObject *parent = nullptr);
+	MessageHandler(ClientWorker *clientWorker, QXmppClient *client, QObject *parent = nullptr);
 	~MessageHandler();
 
 public slots:
+	void handleRosterReceived();
+	void handleLastMessageStampFetched(const QDateTime &stamp);
+
 	/**
 	 * Handles incoming messages from the server.
 	 */
-	void handleMessage(const QXmppMessage &msg);
+	void handleMessage(const QXmppMessage &msg, MessageOrigin origin);
 
 	/**
-	 * Sends a new message to the server and inserts it into the database.
+	 * Send a text message to any JID
 	 */
-	void sendMessage(const QString& toJid, const QString& body, bool isSpoiler, const QString& spoilerHint);
+	void sendMessage(const QString &toJid, const QString &body, bool isSpoiler, const QString &spoilerHint);
+
+	/**
+	 * Sends a chat state notification to the server.
+	 */
+	void sendChatState(const QString &toJid, const QXmppMessage::State state);
 
 	/**
 	 * Sends the corrected version of a message.
@@ -76,7 +90,18 @@ public slots:
 	 */
 	void handleDiscoInfo(const QXmppDiscoveryIq &);
 
+signals:
+	void sendMessageRequested(const QString &toJid,
+				  const QString &body,
+				  bool isSpoiler,
+				  const QString &spoilerHint);
+
+	void retrieveBacklogMessagesRequested(const QString &jid, const QDateTime &stamp);
+
 private slots:
+	void handleConnected();
+	void handleDisonnected();
+
 	/**
 	 * Handles pending messages found in the database.
 	 */
@@ -84,12 +109,36 @@ private slots:
 
 	void sendPendingMessage(const Message &message);
 
+	void handleArchiveMessage(const QString &queryId, const QXmppMessage &message);
+	void handleArchiveResults(const QString &queryId,
+	                          const QXmppResultSetReply &resultSetReply,
+	                          bool complete);
+
+	void retrieveInitialMessages();
+	void retrieveCatchUpMessages(const QDateTime &stamp);
+	void retrieveBacklogMessages(const QString &jid, const QDateTime &last);
+
 private:
 	bool parseMediaUri(Message &message, const QString &uri, bool isBodyPart);
 
+	struct BacklogQueryState {
+		QString chatJid;
+		QDateTime lastTimestamp;
+	};
+
 	ClientWorker *m_clientWorker;
 	QXmppClient *m_client;
 	QXmppMessageReceiptManager m_receiptManager;
-	MessageModel *m_model;
 	QXmppCarbonManager *m_carbonManager;
+	QXmppMamManager *m_mamManager;
+
+	QDateTime m_lastMessageStamp;
+	bool m_lastMessageLoaded = false;
+
+	// All messages after the intitial message
+	QVector<QString> m_runningInitialMessageQueryIds;
+	// Mapping of all running MAM backlog queries to their chat JIDs
+	QMap<QString, BacklogQueryState> m_runningBacklogQueryIds;
+	// query id of the MAM query for catching up all missing messages
+	QString m_runnningCatchUpQueryId;
 };
