@@ -30,18 +30,45 @@
 
 #pragma once
 
+// Qt
 #include <QAbstractListModel>
+// QXmpp
+#include <QXmppMessage.h>
+// Kaidan
 #include "Message.h"
 
-class MessageDb;
+class QTimer;
 class Kaidan;
 
+class ChatState : public QObject
+{
+	Q_OBJECT
+
+public:
+	enum State {
+		None = QXmppMessage::None,
+		Active = QXmppMessage::Active,
+		Inactive = QXmppMessage::Inactive,
+		Gone = QXmppMessage::Gone,
+		Composing = QXmppMessage::Composing,
+		Paused = QXmppMessage::Paused
+	};
+	Q_ENUM(State)
+};
+
+Q_DECLARE_METATYPE(ChatState::State)
+
 class MessageModel : public QAbstractListModel
 {
 	Q_OBJECT
-	Q_PROPERTY(QString currentChatJid READ currentChatJid WRITE setCurrentChatJid NOTIFY currentChatJidChanged)
+
+	Q_PROPERTY(QString currentAccountJid READ currentAccountJid NOTIFY currentAccountJidChanged)
+	Q_PROPERTY(QString currentChatJid READ currentChatJid NOTIFY currentChatJidChanged)
+	Q_PROPERTY(QXmppMessage::State chatState READ chatState NOTIFY chatStateChanged)
+	Q_PROPERTY(bool mamLoading READ mamLoading NOTIFY mamLoadingChanged)
 
 public:
+	// Basically copy from QXmpp, but we need to expose this to QML
 	enum MessageRoles {
 		Timestamp = Qt::UserRole + 1,
 		Id,
@@ -66,7 +93,9 @@ public:
 	};
 	Q_ENUM(MessageRoles)
 
-	MessageModel(MessageDb *msgDb, QObject *parent = nullptr);
+	static MessageModel *instance();
+
+	MessageModel(QObject *parent = nullptr);
 	~MessageModel();
 
 	Q_REQUIRED_RESULT bool isEmpty() const;
@@ -77,11 +106,29 @@ public:
 	Q_INVOKABLE void fetchMore(const QModelIndex &parent) override;
 	Q_INVOKABLE bool canFetchMore(const QModelIndex &parent) const override;
 
+	QString currentAccountJid();
 	QString currentChatJid();
-	void setCurrentChatJid(const QString &currentChatJid);
+	Q_INVOKABLE void setCurrentChat(const QString &accountJid, const QString &chatJid);
+
+	/**
+	 * Determines whether a chat is the currently open chat.
+	 *
+	 * @param accountJid JID of the chat's account
+	 * @param chatJid JID of the chat
+	 *
+	 * @return true if the chat is currently open, otherwise false
+	 */
+	bool isChatCurrentChat(const QString &accountJid, const QString &chatJid) const;
+
+	Q_INVOKABLE void sendMessage(const QString &body, bool isSpoiler, const QString &spoilerHint);
 
 	Q_INVOKABLE bool canCorrectMessage(int index) const;
 
+	/**
+	 * Correct the last message
+	 */
+	Q_INVOKABLE void correctMessage(const QString &msgId, const QString &message);
+
 	/**
 	 * Searches from the most recent to the oldest message to find a given substring (case insensitive).
 	 *
@@ -111,30 +158,65 @@ public:
 	 */
 	Q_INVOKABLE void sendPendingMessages();
 
-signals:
-	void currentChatJidChanged(const QString &currentChatJid);
+	/**
+	  * Returns the current chat state
+	  */
+	QXmppMessage::State chatState() const;
 
-	void addMessageRequested(const Message &msg);
+	/**
+	  * Sends the chat state notification
+	  */
+	void sendChatState(QXmppMessage::State state);
+	Q_INVOKABLE void sendChatState(ChatState::State state);
+
+	bool mamLoading() const;
+	void setMamLoading(bool mamLoading);
+
+signals:
+	void currentAccountJidChanged(const QString &accountJid);
+	void currentChatJidChanged(const QString &currentChatJid);
+	void mamLoadingChanged();
+
+	void addMessageRequested(const Message &message, MessageOrigin origin);
 	void updateMessageRequested(const QString &id,
 	                            const std::function<void (Message &)> &updateMsg);
-	void setMessageDeliveryStateRequested(const QString &msgId, Enums::DeliveryState state, const QString &errText = QString());
 	void pendingMessagesFetched(const QVector<Message> &messages);
 	void sendCorrectedMessageRequested(const Message &msg);
-	void updateMessageInDatabaseRequested(const QString &id,
-	                                      const std::function<void (Message &)> &updateMsg);
+	void chatStateChanged();
+	void sendChatStateRequested(const QString &bareJid, QXmppMessage::State state);
+	void handleChatStateRequested(const QString &bareJid, QXmppMessage::State state);
+	void mamBacklogRetrieved(const QString &accountJid, const QString &jid, const QDateTime &lastStamp, bool complete);
+
+	/**
+	 * Emitted to remove all messages of an account or an account's chat.
+	 *
+	 * @param accountJid JID of the account whose messages are being removed
+	 * @param chatJid JID of the chat whose messages are being removed (optional)
+	 */
+	void removeMessagesRequested(const QString &accountJid, const QString &chatJid = {});
 
 private slots:
 	void handleMessagesFetched(const QVector<Message> &m_messages);
+	void handleMamBacklogRetrieved(const QString &accountJid, const QString &jid, const QDateTime &lastStamp, bool complete);
 
-	void addMessage(Message msg);
+	void addMessage(const Message &msg);
 	void updateMessage(const QString &id,
 	                   const std::function<void (Message &)> &updateMsg);
 
-	void setMessageDeliveryState(const QString &msgId, Enums::DeliveryState state, const QString &errText = QString());
-	void correctMessage(const QString &msgId, const QString &message);
+	void handleMessage(Message msg, MessageOrigin origin);
+	void handleChatState(const QString &bareJid, QXmppMessage::State state);
 
 private:
-	void clearAll();
+	/**
+	 * Removes all messages of an account or an account's chat.
+	 *
+	 * @param accountJid JID of the account whose messages are being removed
+	 * @param chatJid JID of the chat whose messages are being removed (optional)
+	 */
+	void removeMessages(const QString &accountJid, const QString &chatJid = {});
+
+	void removeAllMessages();
+
 	void insertMessage(int i, const Message &msg);
 
 	/**
@@ -143,9 +225,28 @@ private:
 	 */
 	void processMessage(Message &msg);
 
-	MessageDb *m_msgDb;
+	/**
+	 * Shows a notification for the message when needed
+	 *
+	 * @param message message for which a notification might be shown
+	 */
+	void showMessageNotification(const Message &message, MessageOrigin origin) const;
 
 	QVector<Message> m_messages;
+	QString m_currentAccountJid;
 	QString m_currentChatJid;
-	bool m_fetchedAll = false;
+	bool m_fetchedAllFromDb = false;
+	bool m_fetchedAllFromMam = false;
+	bool m_mamLoading = false;
+	QDateTime m_mamBacklogLastStamp;
+
+	QXmppMessage::State m_chatPartnerChatState = QXmppMessage::State::None;
+	QXmppMessage::State m_ownChatState = QXmppMessage::State::None;
+	QTimer *m_composingTimer;
+	QTimer *m_stateTimeoutTimer;
+	QTimer *m_inactiveTimer;
+	QTimer *m_chatPartnerChatStateTimeout;
+	QMap<QString, QXmppMessage::State> m_chatStateCache;
+
+	static MessageModel *s_instance;
 };
