@@ -33,6 +33,8 @@
 #include <QObject>
 #include <QUrl>
 
+#include <QXmppMessage.h>
+
 #include "ClientWorker.h"
 #include "Globals.h"
 
@@ -162,7 +164,13 @@ public:
 	/**
 	 * Returns the timestamp in a format for file names.
 	 */
-	static QString timestampForFileName(const QDateTime &dateTime = QDateTime::currentDateTime());
+	static QString timestampForFileName();
+	static QString timestampForFileName(const QDateTime &dateTime);
+
+	/**
+	 * Returns a human-readable string describing the state of the chat
+	 */
+	Q_INVOKABLE static QString chatStateDescription(const QString &displayName, const QXmppMessage::State state);
 
 private:
 	/**
