@@ -1,7 +1,7 @@
 /*
  *  Kaidan - A user-friendly XMPP client for every device!
  *
- *  Copyright (C) 2016-2020 Kaidan developers and contributors
+ *  Copyright (C) 2016-2021 Kaidan developers and contributors
  *  (see the LICENSE file for a full list of copyright authors)
  *
  *  Kaidan is free software: you can redistribute it and/or modify
@@ -32,8 +32,6 @@
 
 #include <QObject>
 
-#include <ZXing/BarcodeFormat.h>
-#include <ZXing/MultiFormatWriter.h>
 #include <ZXing/BitMatrix.h>
 
 class QImage;
@@ -57,13 +55,21 @@ public:
 	 */
 	Q_INVOKABLE static QImage generateLoginUriQrCode(int edgePixelCount);
 
+	/**
+	 * Gerenates a QR code encoding an XMPP URI containing a given bare JID.
+	 *
+	 * @param edgePixelCount number of pixels as the width and height of the QR code
+	 * @param bareJid bare JID being encoded in an XMPP URI
+	 */
+	Q_INVOKABLE static QImage generateBareJidQrCode(int edgePixelCount, const QString &bareJid);
+
 	/**
 	 * Gerenates a QR code.
 	 *
-	 * @param text string to be encoded as a QR code
 	 * @param edgePixelCount number of pixels as the width and height of the QR code
+	 * @param text string being encoded as a QR code
 	 */
-	Q_INVOKABLE static QImage generateQrCode(const QString &text, int edgePixelCount);
+	Q_INVOKABLE static QImage generateQrCode(int edgePixelCount, const QString &text);
 
 private:
 	/**
