@@ -30,15 +30,8 @@
 
 #include "RegistrationManager.h"
 
-// Qt
-#include <QDomElement>
-#include <QList>
-#include <QObject>
-#include <QSettings>
 // QXmpp
 #include <QXmppBitsOfBinaryDataList.h>
-#include <QXmppClient.h>
-#include <QXmppRegisterIq.h>
 #include <QXmppRegistrationManager.h>
 // Kaidan
 #include "AccountManager.h"
@@ -47,6 +40,7 @@
 #include "Globals.h"
 #include "Kaidan.h"
 #include "RegistrationDataFormModel.h"
+#include "ServerFeaturesCache.h"
 
 RegistrationManager::RegistrationManager(ClientWorker *clientWorker, QXmppClient *client, QSettings *settings, QObject *parent)
 	: QObject(parent),
@@ -61,7 +55,8 @@ RegistrationManager::RegistrationManager(ClientWorker *clientWorker, QXmppClient
 	connect(m_manager, &QXmppRegistrationManager::supportedByServerChanged, this, &RegistrationManager::handleInBandRegistrationSupportedChanged);
 
 	// account creation
-	connect(Kaidan::instance(), &Kaidan::sendRegistrationForm, this, &RegistrationManager::sendRegistrationForm);
+	connect(this, &RegistrationManager::sendRegistrationFormRequested,
+		this, &RegistrationManager::sendRegistrationForm);
 	connect(m_manager, &QXmppRegistrationManager::registrationFormReceived, this, &RegistrationManager::handleRegistrationFormReceived);
 	connect(m_manager, &QXmppRegistrationManager::registrationSucceeded, this, &RegistrationManager::handleRegistrationSucceeded);
 	connect(m_manager, &QXmppRegistrationManager::registrationFailed, this, &RegistrationManager::handleRegistrationFailed);
@@ -71,7 +66,8 @@ RegistrationManager::RegistrationManager(ClientWorker *clientWorker, QXmppClient
 	connect(m_manager, &QXmppRegistrationManager::accountDeleted, m_clientWorker, &ClientWorker::handleAccountDeletedFromServer);
 
 	// password change
-	connect(Kaidan::instance(), &Kaidan::changePassword, this, &RegistrationManager::changePassword);
+	connect(this, &RegistrationManager::changePasswordRequested,
+		this, &RegistrationManager::changePassword);
 	connect(m_manager, &QXmppRegistrationManager::passwordChanged, this, &RegistrationManager::handlePasswordChanged);
 	connect(m_manager, &QXmppRegistrationManager::passwordChangeFailed, this, &RegistrationManager::handlePasswordChangeFailed);
 }
@@ -125,8 +121,27 @@ void RegistrationManager::handleRegistrationFormReceived(const QXmppRegisterIq &
 	bool isFakeForm;
 	QXmppDataForm newDataForm = extractFormFromRegisterIq(iq, isFakeForm);
 
-	// If the data form is not set, there is a problem with the server.
+	// If there is no registration data form, try to use an out-of-band URL.
 	if (newDataForm.fields().isEmpty()) {
+#if QXMPP_VERSION >= QT_VERSION_CHECK(1, 5, 0)
+		// If there is a standardized out-of-band URL, use that.
+		if (!iq.outOfBandUrl().isEmpty()) {
+			emit Kaidan::instance()->registrationOutOfBandUrlReceived(iq.outOfBandUrl());
+			return;
+		}
+#endif
+		// Try to find an out-of-band URL within the instructions element.
+		// Most servers include a text with a link to the website.
+		const auto words = iq.instructions().split(u' ');
+		for (const auto &instructionPart : words) {
+			if (instructionPart.startsWith(u"https://")) {
+				emit Kaidan::instance()->registrationOutOfBandUrlReceived(instructionPart);
+				return;
+			}
+		}
+
+		// If no URL has been found in the instructions, there is a
+		// problem with the server.
 		emit m_clientWorker->connectionErrorChanged(ClientWorker::RegistrationUnsupported);
 		return;
 	}
@@ -211,6 +226,7 @@ void RegistrationManager::handlePasswordChanged(const QString &newPassword)
 	AccountManager::instance()->storePassword();
 	AccountManager::instance()->setHasNewCredentials(false);
 	m_clientWorker->finishTask();
+	emit Kaidan::instance()->passwordChangeSucceeded();
 }
 
 void RegistrationManager::handlePasswordChangeFailed(const QXmppStanza::Error &error)
