@@ -53,6 +53,7 @@ RosterDb::RosterDb(Database *db, QObject *parent)
 
 	connect(this, &RosterDb::fetchItemsRequested, this, &RosterDb::fetchItems);
 	connect(this, &RosterDb::updateItemRequested, this, &RosterDb::updateItem);
+	connect(this, &RosterDb::removeItemsRequested, this, &RosterDb::removeItems);
 }
 
 RosterDb::~RosterDb()
@@ -127,17 +128,6 @@ void RosterDb::addItems(const QVector<RosterItem> &items)
 	m_db->commit();
 }
 
-void RosterDb::removeItem(const QString &jid)
-{
-	QSqlDatabase db = QSqlDatabase::database(DB_CONNECTION);
-	QSqlQuery query(db);
-	Utils::execQuery(
-	        query,
-	        "DELETE FROM Roster WHERE jid = ?",
-	        QVector<QVariant>() << jid
-	);
-}
-
 void RosterDb::updateItem(const QString &jid,
 			  const std::function<void (RosterItem &)> &updateItem)
 {
@@ -169,16 +159,7 @@ void RosterDb::updateItem(const QString &jid,
 			if (rec.isEmpty())
 				return;
 
-			Utils::execQuery(
-			        query,
-			        db.driver()->sqlStatement(
-			                QSqlDriver::UpdateStatement,
-			                DB_TABLE_ROSTER,
-			                rec,
-			                false
-			        ) +
-			        Utils::simpleWhereStatement(db.driver(), "jid", jid)
-			);
+			updateItemByRecord(jid, rec);
 		}
 	}
 }
@@ -218,7 +199,7 @@ void RosterDb::replaceItems(const QHash<QString, RosterItem> &items)
 				setItemName(oldItem.jid(), items[oldItem.jid()].name());
 		} else {
 			// item is not included in newJids -> delete
-			removeItem(oldItem.jid());
+			removeItems({}, oldItem.jid());
 		}
 	}
 
@@ -229,6 +210,12 @@ void RosterDb::replaceItems(const QHash<QString, RosterItem> &items)
 	m_db->commit();
 }
 
+void RosterDb::removeItems(const QString &, const QString &)
+{
+	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
+	Utils::execQuery(query, "DELETE FROM Roster");
+}
+
 void RosterDb::setItemName(const QString &jid, const QString &name)
 {
 	QSqlDatabase db = QSqlDatabase::database(DB_CONNECTION);
@@ -249,12 +236,6 @@ void RosterDb::setItemName(const QString &jid, const QString &name)
 	);
 }
 
-void RosterDb::clearAll()
-{
-	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
-	Utils::execQuery(query, "DELETE FROM Roster");
-}
-
 void RosterDb::fetchItems(const QString &accountId)
 {
 	QSqlQuery query(QSqlDatabase::database(DB_CONNECTION));
@@ -272,3 +253,24 @@ void RosterDb::fetchItems(const QString &accountId)
 
 	emit itemsFetched(items);
 }
+
+void RosterDb::updateItemByRecord(const QString &jid, const QSqlRecord &record)
+{
+	QSqlDatabase db = QSqlDatabase::database(DB_CONNECTION);
+	QSqlQuery query(db);
+
+	QMap<QString, QVariant> keyValuePairs = {
+		{ "jid", jid }
+	};
+
+	Utils::execQuery(
+		query,
+		db.driver()->sqlStatement(
+			QSqlDriver::UpdateStatement,
+			DB_TABLE_ROSTER,
+			record,
+			false
+		) +
+		Utils::simpleWhereStatement(db.driver(), keyValuePairs)
+	);
+}
