@@ -30,20 +30,20 @@
 
 #include "RosterManager.h"
 // Kaidan
+#include "AvatarFileStorage.h"
 #include "Kaidan.h"
+#include "MessageModel.h"
+#include "RosterModel.h"
 #include "VCardManager.h"
 // QXmpp
-#include <QXmppClient.h>
 #include <QXmppRosterManager.h>
 
 RosterManager::RosterManager(QXmppClient *client,
-                             RosterModel *model,
                              AvatarFileStorage *avatarStorage,
                              VCardManager *vCardManager,
                              QObject *parent)
 	: QObject(parent),
 	  m_client(client),
-	  m_model(model),
 	  m_avatarStorage(avatarStorage),
 	  m_vCardManager(vCardManager),
 	  m_manager(client->findExtension<QXmppRosterManager>())
@@ -52,27 +52,30 @@ RosterManager::RosterManager(QXmppClient *client,
 	        this, &RosterManager::populateRoster);
 
 	connect(m_manager, &QXmppRosterManager::itemAdded,
-		this, [this, vCardManager, model] (const QString &jid) {
-		emit model->addItemRequested(RosterItem(m_manager->getRosterEntry(jid)));
-
+		this, [this, vCardManager] (const QString &jid) {
+		emit RosterModel::instance()->addItemRequested(RosterItem(m_manager->getRosterEntry(jid)));
 		vCardManager->requestVCard(jid);
 	});
 
 	connect(m_manager, &QXmppRosterManager::itemChanged,
-		this, [this, model] (const QString &jid) {
-		emit model->updateItemRequested(jid, [=] (RosterItem &item) {
+		this, [this] (const QString &jid) {
+		emit RosterModel::instance()->updateItemRequested(jid, [=] (RosterItem &item) {
 			item.setName(m_manager->getRosterEntry(jid).name());
 		});
 	});
 
-	connect(m_manager, &QXmppRosterManager::itemRemoved, model, &RosterModel::removeItemRequested);
+	connect(m_manager, &QXmppRosterManager::itemRemoved, this, [client](const QString &jid) {
+		const auto accountJid = client->configuration().jidBare();
+		emit MessageModel::instance()->removeMessagesRequested(accountJid, jid);
+		emit RosterModel::instance()->removeItemsRequested(accountJid, jid);
+	});
 
 	connect(m_manager, &QXmppRosterManager::subscriptionReceived,
 			this, [] (const QString &jid) {
 		// emit signal to ask user
-		emit Kaidan::instance()->subscriptionRequestReceived(jid, QString());
+		emit RosterModel::instance()->subscriptionRequestReceived(jid, {});
 	});
-	connect(Kaidan::instance(), &Kaidan::subscriptionRequestAnswered,
+	connect(this, &RosterManager::answerSubscriptionRequestRequested,
 	        this, [=] (QString jid, bool accepted) {
 		if (accepted) {
 			m_manager->acceptSubscription(jid);
@@ -87,9 +90,9 @@ RosterManager::RosterManager(QXmppClient *client,
 	});
 
 	// user actions
-	connect(Kaidan::instance(), &Kaidan::addContact, this, &RosterManager::addContact);
-	connect(Kaidan::instance(), &Kaidan::removeContact, this, &RosterManager::removeContact);
-	connect(Kaidan::instance(), &Kaidan::renameContact, this, &RosterManager::renameContact);
+	connect(this, &RosterManager::addContactRequested, this, &RosterManager::addContact);
+	connect(this, &RosterManager::removeContactRequested, this, &RosterManager::removeContact);
+	connect(this, &RosterManager::renameContactRequested, this, &RosterManager::renameContact);
 }
 
 void RosterManager::populateRoster()
@@ -98,16 +101,16 @@ void RosterManager::populateRoster()
 	// create a new list of contacts
 	QHash<QString, RosterItem> items;
 	const QStringList bareJids = m_manager->getRosterBareJids();
-	const auto currentTime = QDateTime::currentDateTimeUtc();
+	const auto initialTime = QDateTime::fromMSecsSinceEpoch(0);
 	for (const auto &jid : bareJids) {
-		items[jid] = RosterItem(m_manager->getRosterEntry(jid), currentTime);
+		items.insert(jid, RosterItem(m_manager->getRosterEntry(jid), initialTime));
 
 		if (m_avatarStorage->getHashOfJid(jid).isEmpty())
 			m_vCardManager->requestVCard(jid);
 	}
 
 	// replace current contacts with new ones from server
-	emit m_model->replaceItemsRequested(items);
+	emit RosterModel::instance()->replaceItemsRequested(items);
 }
 
 void RosterManager::addContact(const QString &jid, const QString &name, const QString &msg)
