@@ -37,7 +37,6 @@ class QXmppClient;
 class QXmppRosterManager;
 // Kaidan
 class AvatarFileStorage;
-class RosterModel;
 class VCardManager;
 
 class RosterManager : public QObject
@@ -45,9 +44,34 @@ class RosterManager : public QObject
 	Q_OBJECT
 
 public:
-	RosterManager(QXmppClient *client, RosterModel *rosterModel,
-				  AvatarFileStorage *avatarStorage, VCardManager *vCardManager,
-	              QObject *parent = nullptr);
+	RosterManager(QXmppClient *client, AvatarFileStorage *avatarStorage, VCardManager *vCardManager, QObject *parent = nullptr);
+
+signals:
+	/**
+	 * Requests to send subscription request answer (whether it was accepted
+	 * or declined by the user)
+	 */
+	void answerSubscriptionRequestRequested(const QString &jid, bool accepted);
+
+	/**
+	 * Add a contact to your roster
+	 *
+	 * @param nick A simple nick name for the new contact, which should be
+	 *             used to display in the roster.
+	 */
+	void addContactRequested(const QString &jid, const QString &nick, const QString &msg);
+
+	/**
+	 * Remove a contact from your roster
+	 *
+	 * Only the JID is needed.
+	 */
+	void removeContactRequested(const QString &jid);
+
+	/**
+	 * Change a contact's name
+	 */
+	void renameContactRequested(const QString &jid, const QString &newContactName);
 
 public slots:
 	void addContact(const QString &jid, const QString &name, const QString &msg);
@@ -59,7 +83,6 @@ private slots:
 
 private:
 	QXmppClient *m_client;
-	RosterModel *m_model;
 	AvatarFileStorage *m_avatarStorage;
 	VCardManager *m_vCardManager;
 	QXmppRosterManager *m_manager;
