@@ -32,42 +32,61 @@
 
 // Kaidan
 #include "AccountManager.h"
-#include "RosterDb.h"
-#include "MessageModel.h"
 #include "Kaidan.h"
+#include "MessageDb.h"
+#include "MessageModel.h"
+#include "RosterDb.h"
 
-RosterModel::RosterModel(RosterDb *rosterDb, QObject *parent)
-        : QAbstractListModel(parent),
-	  m_rosterDb(rosterDb)
+#include <QXmppUtils.h>
+
+RosterModel *RosterModel::s_instance = nullptr;
+
+RosterModel *RosterModel::instance()
 {
-	connect(rosterDb, &RosterDb::itemsFetched,
+	return s_instance;
+}
+
+RosterModel::RosterModel(QObject *parent)
+	: QAbstractListModel(parent)
+{
+	Q_ASSERT(!s_instance);
+	s_instance = this;
+
+	connect(RosterDb::instance(), &RosterDb::itemsFetched,
 		this, &RosterModel::handleItemsFetched);
 
 	connect(this, &RosterModel::addItemRequested, this, &RosterModel::addItem);
-	connect(this, &RosterModel::addItemRequested, rosterDb, &RosterDb::addItem);
-
-	connect(this, &RosterModel::removeItemRequested,
-	        this, &RosterModel::removeItem);
-	connect(this, &RosterModel::removeItemRequested,
-	        rosterDb, &RosterDb::removeItem);
+	connect(this, &RosterModel::addItemRequested, RosterDb::instance(), &RosterDb::addItem);
 
 	connect(this, &RosterModel::updateItemRequested,
 	        this, &RosterModel::updateItem);
-	connect(this, &RosterModel::updateItemRequested,
-	        rosterDb, &RosterDb::updateItem);
+	connect(this, &RosterModel::updateItemRequested, RosterDb::instance(), &RosterDb::updateItem);
 
 	connect(this, &RosterModel::replaceItemsRequested,
 	        this, &RosterModel::replaceItems);
-	connect(this, &RosterModel::replaceItemsRequested,
-		rosterDb, &RosterDb::replaceItems);
+	connect(this, &RosterModel::replaceItemsRequested, RosterDb::instance(), &RosterDb::replaceItems);
+
+	connect(MessageDb::instance(), &MessageDb::messageAdded,
+	        this, &RosterModel::handleMessageAdded);
 
 	connect(AccountManager::instance(), &AccountManager::jidChanged, this, [=]() {
 		beginResetModel();
 		m_items.clear();
 		endResetModel();
 
-		emit rosterDb->fetchItemsRequested(AccountManager::instance()->jid());
+		emit RosterDb::instance()->fetchItemsRequested(AccountManager::instance()->jid());
 	});
+
+	connect(this, &RosterModel::removeItemsRequested, this, [=](const QString &accountJid, const QString &chatJid) {
+		emit RosterDb::instance()->removeItemsRequested(accountJid, chatJid);
+
+		removeItems(accountJid, chatJid);
+
+		if (accountJid == MessageModel::instance()->currentAccountJid() && chatJid == MessageModel::instance()->currentChatJid())
+			emit Kaidan::instance()->openChatViewRequested();
+	});
+
+	connect(MessageDb::instance(), &MessageDb::messageAdded, this, &RosterModel::handleMessageAdded);
 }
 
 void RosterModel::setMessageModel(MessageModel *model)
@@ -78,9 +97,6 @@ void RosterModel::setMessageModel(MessageModel *model)
 			item.setUnreadMessages(0);
 		});
 	});
-
-	connect(model, &MessageModel::addMessageRequested,
-	        this, &RosterModel::handleMessageAdded);
 }
 
 bool RosterModel::isEmpty() const
@@ -136,10 +152,10 @@ std::optional<const RosterItem> RosterModel::findItem(const QString &jid) const
 	return std::nullopt;
 }
 
-QString RosterModel::itemName(const QString &jid) const
+QString RosterModel::itemName(const QString &, const QString &jid) const
 {
 	if (auto item = findItem(jid))
-		return item->name();
+		return determineItemName(jid, item->name());
 	return {};
 }
 
@@ -153,7 +169,7 @@ void RosterModel::handleItemsFetched(const QVector<RosterItem> &items)
 
 void RosterModel::addItem(const RosterItem &item)
 {
-	insertContact(positionToInsert(item), item);
+	insertItem(positionToInsert(item), item);
 }
 
 void RosterModel::removeItem(const QString &jid)
@@ -223,7 +239,21 @@ void RosterModel::replaceItems(const QHash<QString, RosterItem> &items)
 	handleItemsFetched(newItems);
 }
 
-void RosterModel::handleMessageAdded(const Message &message)
+void RosterModel::removeItems(const QString &accountJid, const QString &jid)
+{
+	for (int i = 0; i < m_items.size(); i++) {
+		RosterItem &item = m_items[i];
+
+		if (AccountManager::instance()->jid() == accountJid && (item.jid().isEmpty() || item.jid() == jid)) {
+			beginRemoveRows(QModelIndex(), i, i);
+			m_items.remove(i);
+			endRemoveRows();
+			return;
+		}
+	}
+}
+
+void RosterModel::handleMessageAdded(const Message &message, MessageOrigin origin)
 {
 	const auto contactJid = message.sentByMe() ? message.to() : message.from();
 	auto itr = std::find_if(m_items.begin(), m_items.end(), [&contactJid](const RosterItem &item) {
@@ -234,8 +264,9 @@ void RosterModel::handleMessageAdded(const Message &message)
 	if (itr == m_items.end())
 		return;
 
-	// new message is older than most recent event
-	if (itr->lastExchanged() > message.stamp())
+	// only set new message if it's newer
+	// allow setting old message if the current message is empty
+	if (!itr->lastMessage().isEmpty() && itr->lastExchanged() >= message.stamp())
 		return;
 
 	QVector<int> changedRoles = {
@@ -257,16 +288,24 @@ void RosterModel::handleMessageAdded(const Message &message)
 	if (message.sentByMe()) {
 		// if we sent a message (with another device), reset counter
 		newUnreadMessages = 0;
-	} else if (Kaidan::instance()->messageModel()->currentChatJid() != contactJid) {
-		// increase counter, if chat isn't open
-		newUnreadMessages = itr->unreadMessages() + 1;
+	} else if (MessageModel::instance()->currentChatJid() != contactJid) {
+		// increase counter, if chat isn't open and message is new
+		switch (origin) {
+		case MessageOrigin::Stream:
+		case MessageOrigin::UserInput:
+		case MessageOrigin::MamCatchUp:
+			newUnreadMessages = itr->unreadMessages() + 1;
+		case MessageOrigin::MamBacklog:
+		case MessageOrigin::MamInitial:
+			break;
+		}
 	}
 
 	if (newUnreadMessages.has_value()) {
 		itr->setUnreadMessages(*newUnreadMessages);
 		changedRoles << int(UnreadMessagesRole);
 
-		emit m_rosterDb->updateItemRequested(contactJid, [=](RosterItem &item) {
+		emit RosterDb::instance()->updateItemRequested(contactJid, [=](RosterItem &item) {
 			item.setUnreadMessages(*newUnreadMessages);
 		});
 	}
@@ -280,10 +319,10 @@ void RosterModel::handleMessageAdded(const Message &message)
 	updateItemPosition(i);
 }
 
-void RosterModel::insertContact(int i, const RosterItem &item)
+void RosterModel::insertItem(int index, const RosterItem &item)
 {
-	beginInsertRows(QModelIndex(), i, i);
-	m_items.insert(i, item);
+	beginInsertRows(QModelIndex(), index, index);
+	m_items.insert(index, item);
 	endInsertRows();
 }
 
@@ -314,3 +353,8 @@ int RosterModel::positionToInsert(const RosterItem &item)
 	// append
 	return m_items.size();
 }
+
+QString RosterModel::determineItemName(const QString &jid, const QString &name) const
+{
+	return name.isEmpty() ? QXmppUtils::jidToUser(jid) : name;
+}
