@@ -39,9 +39,9 @@
 #include "RosterItem.h"
 
 class Kaidan;
-class RosterDb;
 class MessageModel;
 class Message;
+enum class MessageOrigin : quint8;
 
 class RosterModel : public QAbstractListModel
 {
@@ -56,7 +56,9 @@ public:
 		LastMessageRole,
 	};
 
-	RosterModel(RosterDb *rosterDb, QObject *parent = nullptr);
+	static RosterModel *instance();
+
+	RosterModel(QObject *parent = nullptr);
 
 	void setMessageModel(MessageModel *model);
 
@@ -66,11 +68,16 @@ public:
 	Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
 
 	/**
-	 * Retrieves the name of a roster item.
+	 * Retrieves the name of a roster item or its JID's local part.
 	 *
-	 * @return Name of the roster item or a null string
+	 * @param accountJid JID of the account whose roster item is retrieved
+	 * @param jid JID of the roster item
+	 *
+	 * @return the name of the roster item, or
+	 * the local part of its JID if the found roster item has no name, or
+	 * an empty string if no roster item with the given JID could be found
 	 */
-	Q_INVOKABLE QString itemName(const QString &jid) const;
+	Q_INVOKABLE QString itemName(const QString &accountJid, const QString &jid) const;
 
 signals:
 	void addItemRequested(const RosterItem &item);
@@ -79,6 +86,19 @@ signals:
 	                         const std::function<void (RosterItem &)> &updateItem);
 	void replaceItemsRequested(const QHash<QString, RosterItem> &items);
 
+	/**
+	 * Emitted to remove all roster items of an account or a specific roster item.
+	 *
+	 * @param accountJid JID of the account whose roster items are being removed
+	 * @param jid JID of the roster item being removed (optional)
+	 */
+	void removeItemsRequested(const QString &accountJid, const QString &jid = {});
+
+	/**
+	 * Emitted, whan a subscription request was received
+	 */
+	void subscriptionRequestReceived(const QString &from, const QString &msg);
+
 private slots:
 	void handleItemsFetched(const QVector<RosterItem> &items);
 
@@ -87,7 +107,16 @@ private slots:
 	void updateItem(const QString &jid,
 	                const std::function<void (RosterItem &)> &updateItem);
 	void replaceItems(const QHash<QString, RosterItem> &items);
-	void handleMessageAdded(const Message &message);
+
+	/**
+	 * Removes all roster items of an account or a specific roster item.
+	 *
+	 * @param accountJid JID of the account whose roster items are being removed
+	 * @param jid JID of the roster item being removed (optional)
+	 */
+	void removeItems(const QString &accountJid, const QString &jid = {});
+
+	void handleMessageAdded(const Message &message, MessageOrigin origin);
 
 private:
 	/**
@@ -95,10 +124,22 @@ private:
 	 */
 	std::optional<const RosterItem> findItem(const QString &jid) const;
 
-	void insertContact(int i, const RosterItem &item);
+	void insertItem(int index, const RosterItem &item);
 	int updateItemPosition(int currentIndex);
 	int positionToInsert(const RosterItem &item);
 
-	RosterDb *m_rosterDb;
+	/**
+	 * Determines a suitable roster item's name.
+	 *
+	 * @param jid JID of the roster item
+	 * @param name name of the roster item which can be empty
+	 *
+	 * @return the passed item name if it is not empty, otherwise the local
+	 * part of the passed JID
+	 */
+	QString determineItemName(const QString &jid, const QString &name) const;
+
 	QVector<RosterItem> m_items;
+
+	static RosterModel *s_instance;
 };
