@@ -32,32 +32,35 @@
 
 // Qt
 #include <QDateTime>
-#include <QDebug>
 #include <QFileInfo>
 // QXmpp
 #include <QXmppUtils.h>
+#include "qxmpp-exts/QXmppUploadManager.h"
 // Kaidan
-#include "MediaUtils.h"
 #include "Kaidan.h"
+#include "MediaUtils.h"
+#include "MessageModel.h"
 #include "RosterManager.h"
+#include "ServerFeaturesCache.h"
 #include "TransferCache.h"
 
 UploadManager::UploadManager(QXmppClient *client, RosterManager* rosterManager,
                              QObject* parent)
 	: QObject(parent),
 	  m_client(client),
+	  m_manager(new QXmppUploadManager),
 	  m_rosterManager(rosterManager)
 {
-	client->addExtension(&m_manager);
+	client->addExtension(m_manager);
 
-	connect(Kaidan::instance(), &Kaidan::sendFile, this, &UploadManager::sendFile);
+	connect(this, &UploadManager::sendFileRequested, this, &UploadManager::sendFile);
 
-	connect(&m_manager, &QXmppUploadManager::serviceFoundChanged, this, [=]() {
-		Kaidan::instance()->serverFeaturesCache()->setHttpUploadSupported(m_manager.serviceFound());
+	connect(m_manager, &QXmppUploadManager::serviceFoundChanged, this, [=]() {
+		Kaidan::instance()->serverFeaturesCache()->setHttpUploadSupported(m_manager->serviceFound());
 	});
-	connect(&m_manager, &QXmppUploadManager::uploadSucceeded,
+	connect(m_manager, &QXmppUploadManager::uploadSucceeded,
 	        this, &UploadManager::handleUploadSucceeded);
-	connect(&m_manager, &QXmppUploadManager::uploadFailed,
+	connect(m_manager, &QXmppUploadManager::uploadFailed,
 	        this, &UploadManager::handleUploadFailed);
 }
 
@@ -77,7 +80,7 @@ void UploadManager::sendFile(const QString &jid, const QUrl &fileUrl, const QStr
 
 	// toString() is used for android's content:/image:-URLs
 	QFileInfo file(fileUrl.isLocalFile() ? fileUrl.toLocalFile() : fileUrl.toString());
-	const QXmppHttpUpload* upload = m_manager.uploadFile(file);
+	const QXmppHttpUpload* upload = m_manager->uploadFile(file);
 	const QMimeType mimeType = MediaUtils::mimeType(fileUrl);
 	const MessageType messageType = MediaUtils::messageType(mimeType);
 	const QString msgId = QXmppUtils::generateStanzaHash();
@@ -99,7 +102,7 @@ void UploadManager::sendFile(const QString &jid, const QUrl &fileUrl, const QStr
 	emit Kaidan::instance()->transferCache()->addJobRequested(msgId, upload->bytesTotal());
 	m_messages.insert(upload->id(), msg);
 
-	emit Kaidan::instance()->messageModel()->addMessageRequested(*msg);
+	emit MessageModel::instance()->addMessageRequested(*msg, MessageOrigin::UserInput);
 
 	connect(upload, &QXmppHttpUpload::bytesSentChanged, this, [=] () {
 		emit Kaidan::instance()->transferCache()->setJobBytesSentRequested(
@@ -118,7 +121,7 @@ void UploadManager::handleUploadSucceeded(const QXmppHttpUpload *upload)
 	                     ? oobUrl
 	                     : originalMsg->body() + "\n" + oobUrl;
 
-	emit Kaidan::instance()->messageModel()->updateMessageRequested(originalMsg->id(), [=] (Message &msg) {
+	emit MessageModel::instance()->updateMessageRequested(originalMsg->id(), [=] (Message &msg) {
 		msg.setOutOfBandUrl(oobUrl);
 	});
 
@@ -131,11 +134,16 @@ void UploadManager::handleUploadSucceeded(const QXmppHttpUpload *upload)
 
 	bool success = m_client->sendPacket(m);
 	if (success) {
-		emit Kaidan::instance()->messageModel()->setMessageDeliveryStateRequested(
-			originalMsg->id(), Enums::DeliveryState::Sent);
+		emit MessageModel::instance()->updateMessageRequested(originalMsg->id(), [](Message &msg) {
+			msg.setDeliveryState(Enums::DeliveryState::Sent);
+			msg.setErrorText({});
+		});
 	} else {
 		emit Kaidan::instance()->passiveNotificationRequested(tr("Message could not be sent."));
-		emit Kaidan::instance()->messageModel()->setMessageDeliveryStateRequested(originalMsg->id(), Enums::DeliveryState::Error, "Message could not be sent.");
+		emit MessageModel::instance()->updateMessageRequested(originalMsg->id(), [](Message &msg) {
+			msg.setDeliveryState(Enums::DeliveryState::Error);
+			msg.setErrorText(QStringLiteral("Message could not be sent."));
+		});
 	}
 
 	m_messages.remove(upload->id());
