@@ -33,11 +33,12 @@
 // Qt
 #include <QObject>
 #include <QMap>
-// QXmpp
-#include "qxmpp-exts/QXmppUploadManager.h"
 
 class Message;
 class RosterManager;
+class QXmppClient;
+class QXmppHttpUpload;
+class QXmppUploadManager;
 
 /**
  * @class UploadManager Class for handling and starting HTTP File Uploads
@@ -55,11 +56,16 @@ public:
 
 signals:
 	/**
-	 * Connect to it to be notified about progress on uploads
+	 * The upload progress of a file upload has changed
 	 */
-	void uploadProgressMade(QString msgId, unsigned long sent, unsigned long total);
+	void uploadProgressMade(const QString &msgId, quint64 sent, quint64 total);
 
-public slots:
+	/**
+	 * Upload and send file
+	 */
+	void sendFileRequested(const QString &jid, const QUrl &fileUrl, const QString &body);
+
+private slots:
 	/**
 	 * Starts uploading a file
 	 */
@@ -70,7 +76,7 @@ public slots:
 
 private:
 	QXmppClient *m_client;
-	QXmppUploadManager m_manager;
+	QXmppUploadManager *m_manager;
 	RosterManager *m_rosterManager;
 
 	QMap<int, Message*> m_messages;
