@@ -30,12 +30,14 @@
 
 #include "VCardManager.h"
 
-#include <QXmppClient.h>
+// QXmpp
 #include <QXmppUtils.h>
+#include <QXmppVCardManager.h>
 #include <QXmppVCardIq.h>
-
+// Kaidan
 #include "AvatarFileStorage.h"
 #include "Kaidan.h"
+#include "VCardCache.h"
 
 VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, AvatarFileStorage *avatars, QObject *parent)
 	: QObject(parent), m_clientWorker(clientWorker), m_client(client), m_manager(client->findExtension<QXmppVCardManager>()), m_avatarStorage(avatars)
@@ -43,8 +45,8 @@ VCardManager::VCardManager(ClientWorker *clientWorker, QXmppClient *client, Avat
 	connect(m_manager, &QXmppVCardManager::vCardReceived, this, &VCardManager::handleVCardReceived);
 	connect(m_client, &QXmppClient::presenceReceived, this, &VCardManager::handlePresenceReceived);
 	connect(m_manager, &QXmppVCardManager::clientVCardReceived, this, &VCardManager::handleClientVCardReceived);
-	connect(Kaidan::instance(), &Kaidan::vCardRequested, this, &VCardManager::requestVCard);
-	connect(Kaidan::instance(), &Kaidan::changeDisplayName, this, &VCardManager::changeNickname);
+	connect(this, &VCardManager::vCardRequested, this, &VCardManager::requestVCard);
+	connect(this, &VCardManager::changeDisplayNameRequested, this, &VCardManager::changeNickname);
 
 	// Currently we're not requesting the own VCard on every connection because it is probably
 	// way too resource intensive on mobile connections with many reconnects.
@@ -81,6 +83,8 @@ void VCardManager::handleClientVCardReceived()
 {
 	if (!m_nicknameToBeSetAfterReceivingCurrentVCard.isEmpty())
 		changeNicknameAfterReceivingCurrentVCard();
+
+	m_clientWorker->caches()->vCardCache->setVCard(m_client->configuration().jidBare(), m_manager->clientVCard());
 }
 
 void VCardManager::handlePresenceReceived(const QXmppPresence &presence)
