@@ -31,13 +31,13 @@
 #pragma once
 
 #include <QObject>
-#include <QString>
-#include <QXmppVCardManager.h>
-#include <QXmppPresence.h>
 
 class AvatarFileStorage;
 class ClientWorker;
 class QXmppClient;
+class QXmppPresence;
+class QXmppVCardIq;
+class QXmppVCardManager;
 
 class VCardManager : public QObject
 {
@@ -86,14 +86,6 @@ public:
 	 */
 	bool executePendingNicknameChange();
 
-public slots:
-	/**
-	 * Changes the user's nickname.
-	 *
-	 * @param nickname name that is shown to contacts after the update
-	 */
-	void changeNickname(const QString &nickname);
-
 signals:
 	/**
 	 * Emitted when any vCard is received.
@@ -102,6 +94,17 @@ signals:
 	 */
 	void vCardReceived(const QXmppVCardIq &vCard);
 
+	void vCardRequested(const QString &jid);
+	void changeDisplayNameRequested(const QString &displayName);
+
+private slots:
+	/**
+	 * Changes the user's nickname.
+	 *
+	 * @param nickname name that is shown to contacts after the update
+	 */
+	void changeNickname(const QString &nickname);
+
 private:
 	/**
 	 * Changes the nickname which was cached to be set after receiving the current vCard.
