@@ -42,39 +42,66 @@
 
 // QXmpp
 #include <QXmppClient.h>
+#include <QXmppDiscoveryIq.h>
+#include <QXmppVCardIq.h>
+#include <QXmppRegisterIq.h>
+#include <QXmppResultSet.h>
 #include <QXmppVersionIq.h>
 
 // Kaidan
 #include "AccountManager.h"
+#include "AudioDeviceModel.h"
 #include "AvatarFileStorage.h"
 #include "BitsOfBinaryImageProvider.h"
+#include "CameraModel.h"
 #include "CredentialsGenerator.h"
 #include "CredentialsValidator.h"
 #include "DataFormModel.h"
+#include "DiscoveryManager.h"
 #include "EmojiModel.h"
 #include "Enums.h"
+#include "GuiStyle.h"
 #include "Kaidan.h"
-#include "Message.h"
-#include "MessageModel.h"
-#include "QmlUtils.h"
-#include "RegistrationDataFormFilterModel.h"
-#include "RegistrationManager.h"
-#include "RosterModel.h"
-#include "RosterFilterProxyModel.h"
-#include "StatusBar.h"
-#include "ServerListModel.h"
-#include "QrCodeGenerator.h"
-#include "QrCodeScannerFilter.h"
-#include "VCardModel.h"
-#include "UserDevicesModel.h"
-#include "CameraModel.h"
-#include "AudioDeviceModel.h"
 #include "MediaUtils.h"
 #include "MediaRecorder.h"
-#include "GuiStyle.h"
+#include "Message.h"
+#include "MessageModel.h"
+#include "MessageHandler.h"
+#include "QmlUtils.h"
+#include "QrCodeGenerator.h"
+#include "QrCodeScannerFilter.h"
+#include "RegistrationDataFormFilterModel.h"
+#include "RegistrationManager.h"
+#include "RosterManager.h"
+#include "RosterModel.h"
+#include "RosterFilterProxyModel.h"
+#include "ServerFeaturesCache.h"
+#include "ServerListModel.h"
+#include "StatusBar.h"
+#include "TransferCache.h"
+#include "UploadManager.h"
+#include "UserDevicesModel.h"
+#include "VCardModel.h"
+#include "VCardManager.h"
+#include "VersionManager.h"
 
+Q_DECLARE_METATYPE(Qt::ApplicationState)
+
+Q_DECLARE_METATYPE(QXmppClient::State)
+#if QXMPP_VERSION < QT_VERSION_CHECK(1, 4, 0)
+Q_DECLARE_METATYPE(QXmppMessage)
+#endif
+Q_DECLARE_METATYPE(QXmppMessage::State)
+Q_DECLARE_METATYPE(QXmppDiscoveryIq);
+Q_DECLARE_METATYPE(QXmppPresence)
+Q_DECLARE_METATYPE(QXmppStanza::Error)
+Q_DECLARE_METATYPE(QXmppResultSetReply);
+Q_DECLARE_METATYPE(QXmppVCardIq)
 Q_DECLARE_METATYPE(QXmppVersionIq)
 
+Q_DECLARE_METATYPE(std::function<void(RosterItem&)>)
+Q_DECLARE_METATYPE(std::function<void(Message&)>)
+
 #ifdef STATIC_BUILD
 #include "static_plugins.h"
 #endif
@@ -207,23 +234,27 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 #endif // APPIMAGE
 
 	// register qMetaTypes
-	qRegisterMetaType<RosterItem>("RosterItem");
-	qRegisterMetaType<RosterModel*>("RosterModel*");
-	qRegisterMetaType<Message>("Message");
-	qRegisterMetaType<MessageModel*>("MessageModel*");
-	qRegisterMetaType<AvatarFileStorage*>("AvatarFileStorage*");
-	qRegisterMetaType<QXmppPresence>("QXmppPresence");
-	qRegisterMetaType<Qt::ApplicationState>("Qt::ApplicationState");
-	qRegisterMetaType<QXmppClient::State>("QXmppClient::State");
-	qRegisterMetaType<MessageType>("MessageType");
-	qRegisterMetaType<TransferJob*>("TransferJob*");
-	qRegisterMetaType<QmlUtils*>("QmlUtils*");
-	qRegisterMetaType<QVector<Message>>("QVector<Message>");
-	qRegisterMetaType<QVector<RosterItem>>("QVector<RosterItem>");
-	qRegisterMetaType<QHash<QString,RosterItem>>("QHash<QString,RosterItem>");
-	qRegisterMetaType<std::function<void(RosterItem&)>>("std::function<void(RosterItem&)>");
-	qRegisterMetaType<std::function<void(Message&)>>("std::function<void(Message&)>");
-	qRegisterMetaType<QXmppVCardIq>("QXmppVCardIq");
+	qRegisterMetaType<RosterItem>();
+	qRegisterMetaType<RosterModel*>();
+	qRegisterMetaType<RosterManager*>();
+	qRegisterMetaType<Message>();
+	qRegisterMetaType<MessageModel*>();
+	qRegisterMetaType<MessageHandler*>();
+	qRegisterMetaType<DiscoveryManager*>();
+	qRegisterMetaType<UploadManager*>();
+	qRegisterMetaType<VCardManager*>();
+	qRegisterMetaType<VersionManager*>();
+	qRegisterMetaType<RegistrationManager*>();
+	qRegisterMetaType<AvatarFileStorage*>();
+	qRegisterMetaType<QXmppPresence>();
+	qRegisterMetaType<TransferJob*>();
+	qRegisterMetaType<QmlUtils*>();
+	qRegisterMetaType<QVector<Message>>();
+	qRegisterMetaType<QVector<RosterItem>>();
+	qRegisterMetaType<QHash<QString,RosterItem>>();
+	qRegisterMetaType<std::function<void(RosterItem&)>>();
+	qRegisterMetaType<std::function<void(Message&)>>();
+	qRegisterMetaType<QXmppVCardIq>();
 	qRegisterMetaType<QMimeType>();
 	qRegisterMetaType<CameraInfo>();
 	qRegisterMetaType<AudioDeviceInfo>();
@@ -232,15 +263,20 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<AudioEncoderSettings>();
 	qRegisterMetaType<VideoEncoderSettings>();
 	qRegisterMetaType<CredentialsValidator*>();
-	qRegisterMetaType<QXmppStanza::Error>("QXmppStanza::Error");
 	qRegisterMetaType<QXmppVersionIq>();
 
 	// Enums for c++ member calls using enums
+	qRegisterMetaType<Qt::ApplicationState>();
+	qRegisterMetaType<QXmppClient::State>();
+	qRegisterMetaType<QXmppMessage::State>();
+	qRegisterMetaType<QXmppStanza::Error>();
+	qRegisterMetaType<MessageType>();
 	qRegisterMetaType<Enums::ConnectionState>();
 	qRegisterMetaType<ClientWorker::ConnectionError>();
 	qRegisterMetaType<Enums::MessageType>();
 	qRegisterMetaType<Presence::Availability>();
 	qRegisterMetaType<Enums::DeliveryState>();
+	qRegisterMetaType<MessageOrigin>();
 	qRegisterMetaType<CommonEncoderSettings::EncodingQuality>();
 	qRegisterMetaType<CommonEncoderSettings::EncodingMode>();
 	qRegisterMetaType<AudioDeviceModel::Mode>();
@@ -250,6 +286,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qRegisterMetaType<MediaRecorder::Status>();
 	qRegisterMetaType<MediaRecorder::Error>();
 	qRegisterMetaType<ServerListModel::Role>();
+	qRegisterMetaType<ChatState::State>();
+
+	// QXmpp
+	qRegisterMetaType<QXmppResultSetReply>();
+	qRegisterMetaType<QXmppMessage>();
+	qRegisterMetaType<QXmppDiscoveryIq>();
 
 	// Qt-Translator
 	QTranslator qtTranslator;
@@ -302,7 +344,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	//
 	// Kaidan back-end
 	//
-	Kaidan kaidan(&app, !parser.isSet("disable-xml-log"));
+	Kaidan kaidan(!parser.isSet("disable-xml-log"));
 
 #if !defined(Q_OS_IOS) && !defined(Q_OS_ANDROID)
 	// receive messages from other instances of Kaidan
@@ -337,7 +379,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 		qputenv("QT_QUICK_CONTROLS_STYLE", defaultStyle.toLatin1());
 	}
 
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_MACOS)
 	QApplication::setStyle(QStringLiteral("breeze"));
 #endif
 
@@ -385,7 +427,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterUncreatableType<DataFormModel>(APPLICATION_ID, 1, 0, "DataFormModel", "Cannot create object; only enums defined!");
 	qmlRegisterUncreatableType<Presence>(APPLICATION_ID, 1, 0, "Presence", "Cannot create object; only enums defined!");
 	qmlRegisterUncreatableType<RegistrationManager>(APPLICATION_ID, 1, 0, "RegistrationManager", "Cannot create object; only enums defined!");
+	qmlRegisterUncreatableType<ChatState>(APPLICATION_ID, 1, 0, "ChatState", "Cannot create object; only enums defined");
+	qmlRegisterUncreatableType<RosterModel>(APPLICATION_ID, 1, 0, "RosterModel", "Cannot create object; only enums defined!");
+	qmlRegisterUncreatableType<TransferCache>(APPLICATION_ID, 1, 0, "TransferCache", "TransferCache type usable");
+	qmlRegisterUncreatableType<ServerFeaturesCache>(APPLICATION_ID, 1, 0, "ServerFeaturesCache", "ServerFeaturesCache type usable");
 
+	qmlRegisterUncreatableMetaObject(ChatState::staticMetaObject, APPLICATION_ID, 1, 0, "ChatState", "Can't create object; only enums defined!");
 	qmlRegisterUncreatableMetaObject(Enums::staticMetaObject, APPLICATION_ID, 1, 0, "Enums", "Can't create object; only enums defined!");
 
 	qmlRegisterSingletonType<MediaUtils>("MediaUtils", 0, 1, "MediaUtilsInstance", [](QQmlEngine *, QJSEngine *) {
@@ -405,6 +452,12 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 	qmlRegisterSingletonType<AccountManager>(APPLICATION_ID, 1, 0, "AccountManager", [](QQmlEngine *, QJSEngine *) {
 		return static_cast<QObject *>(AccountManager::instance());
 	});
+	qmlRegisterSingletonType<RosterModel>(APPLICATION_ID, 1, 0, "RosterModel", [](QQmlEngine *, QJSEngine *) {
+		return static_cast<QObject *>(RosterModel::instance());
+	});
+	qmlRegisterSingletonType<MessageModel>(APPLICATION_ID, 1, 0, "MessageModel", [](QQmlEngine *, QJSEngine *) {
+		return static_cast<QObject *>(MessageModel::instance());
+	});
 
 	engine.load(QUrl("qrc:/qml/main.qml"));
 	if (engine.rootObjects().isEmpty())
