@@ -7,7 +7,7 @@ echo "Rendering logos"
 echo "*****************************************"
 
 rendersvg() {
-    inkscape -z -e $2 -w $3 -h $3 $1 >/dev/null
+    inkscape -o $2 -w $3 -h $3 $1 >/dev/null
     optipng -quiet -o7 $2 >/dev/null
     advpng -z4 $2 >/dev/null
 }
@@ -19,10 +19,22 @@ androidlogo() {
     rendersvg $KAIDAN_SOURCES/data/images/kaidan.svg "$KAIDAN_SOURCES/misc/android/res/mipmap-$1/logo.png" $(( $2 * 4 ))
 }
 
+# App icons for ECM
+app_icon() {
+    rendersvg $KAIDAN_SOURCES/data/images/kaidan.svg "$KAIDAN_SOURCES/misc/app-icons/$1-kaidan.png" $1
+    optipng -o9 "$KAIDAN_SOURCES/misc/app-icons/$1-kaidan.png"
+}
+
+mkdir -p $KAIDAN_SOURCES/misc/windows
+
+app_icon 16
+app_icon 32
+app_icon 48
+app_icon 256
+
 androidlogo ldpi 36
 androidlogo mdpi 48
 androidlogo hdpi 72
 androidlogo xhdpi 96
 androidlogo xxhdpi 144
 androidlogo xxxhdpi 192
-
